<?php

$LANG = array(
    'organization' => 'Organisasjon',
    'name' => 'Navn',
    'website' => 'Nettside',
    'work_phone' => 'Telefon (arbeid)',
    'address' => 'Adresse',
    'address1' => 'Gate',
    'address2' => 'Husnummer',
    'city' => 'By',
    'state' => 'Fylke',
    'postal_code' => 'Postnummer',
    'country_id' => 'Land',
    'contacts' => 'Kontakter',
    'first_name' => 'Fornavn',
    'last_name' => 'Etternavn',
    'phone' => 'Telefon',
    'email' => 'E-post',
    'additional_info' => 'Tilleggsinfo',
    'payment_terms' => 'Betalingsvilkår',
    'currency_id' => 'Valuta',
    'size_id' => 'Antall ansatte',
    'industry_id' => 'Sektor',
    'private_notes' => 'Private notater',
    'invoice' => 'Faktura',
    'client' => 'Kunde',
    'invoice_date' => 'Faktureringsdato',
    'due_date' => 'Forfallsdato',
    'invoice_number' => 'Fakturanummer',
    'invoice_number_short' => 'Faktura #',
    'po_number' => 'Ordrenummer',
    'po_number_short' => 'Ordre #',
    'frequency_id' => 'Frekvens',
    'discount' => 'Rabatter:',
    'taxes' => 'Skatter',
    'tax' => 'Skatt',
    'item' => 'Produkt',
    'description' => 'Beskrivelse',
    'unit_cost' => 'Stykkpris',
    'quantity' => 'Antall',
    'line_total' => 'Sum',
    'subtotal' => 'Totalbeløp',
    'paid_to_date' => 'Betalt til Dato',
    'balance_due' => 'Gjenstående',
    'invoice_design_id' => 'Design',
    'terms' => 'Vilkår',
    'your_invoice' => 'Din faktura',
    'remove_contact' => 'Fjern kontakt',
    'add_contact' => 'Legg til kontakt',
    'create_new_client' => 'Opprett ny kunde',
    'edit_client_details' => 'Endre kundedetaljer',
    'enable' => 'Aktiver',
    'learn_more' => 'Lær mer',
    'manage_rates' => 'Administrer priser',
    'note_to_client' => 'Merknad til kunde',
    'invoice_terms' => 'Vilkår for fakturaen',
    'save_as_default_terms' => 'Lagre som standard vilkår',
    'download_pdf' => 'Last ned PDF',
    'pay_now' => 'Betal nå',
    'save_invoice' => 'Lagre fakturaen',
    'clone_invoice' => 'Kopier faktura',
    'archive_invoice' => 'Arkiver fakturaen',
    'delete_invoice' => 'Slett faktura',
    'email_invoice' => 'E-postfaktura',
    'enter_payment' => 'Oppgi betaling',
    'tax_rates' => 'Skattesatser',
    'rate' => 'Sats',
    'settings' => 'Innstillinger',
    'enable_invoice_tax' => 'Aktiver for å spesifisere en <b>fakturaskatt</b>',
    'enable_line_item_tax' => 'Aktiver for å spesifisere <b>produktlinje-skatt</b>',
    'dashboard' => 'Skrivebord',
    'dashboard_totals_in_all_currencies_help' => 'Note: add a :link named ":name" to show the totals using a single base currency.',
    'clients' => 'Kunder',
    'invoices' => 'Fakturaer',
    'payments' => 'Betalinger',
    'credits' => 'Krediter',
    'history' => 'Historie',
    'search' => 'Søk',
    'sign_up' => 'Registrer deg',
    'guest' => 'Gjest',
    'company_details' => 'Firmainformasjon',
    'online_payments' => 'Nettbetalinger',
    'notifications' => 'Varsler',
    'import_export' => 'Import | Eksport',
    'done' => 'Ferdig',
    'save' => 'Lagre',
    'create' => 'Lag',
    'upload' => 'Last opp',
    'import' => 'Importer',
    'download' => 'Last ned',
    'cancel' => 'Avbryt',
    'close' => 'Lukk',
    'provide_email' => 'Vennligst oppgi en gyldig e-postadresse',
    'powered_by' => 'Drevet av',
    'no_items' => 'Ingen elementer',
    'recurring_invoices' => 'Gjentakende Fakturaer',
    'recurring_help' => '<p>Automatically send clients the same invoices weekly, bi-monthly, monthly, quarterly or annually. </p>
        <p>Use :MONTH, :QUARTER or :YEAR for dynamic dates. Basic math works as well, for example :MONTH-1.</p>
        <p>Examples of dynamic invoice variables:</p>
        <ul>
          <li>"Gym membership for the month of :MONTH" >> "Gym membership for the month of July"</li>
          <li>":YEAR+1 yearly subscription" >> "2015 Yearly Subscription"</li>
          <li>"Retainer payment for :QUARTER+1" >> "Retainer payment for Q2"</li>
        </ul>',
    'recurring_quotes' => 'Recurring Quotes',
    'in_total_revenue' => 'totale inntekter',
    'billed_client' => 'fakturert kunde',
    'billed_clients' => 'fakturerte kunder',
    'active_client' => 'aktiv kunde',
    'active_clients' => 'aktive kunder',
    'invoices_past_due' => 'Forfalte Fakturaer',
    'upcoming_invoices' => 'Forestående Fakturaer',
    'average_invoice' => 'Gjennomsnittlige fakturaer',
    'archive' => 'Arkiv',
    'delete' => 'Slett',
    'archive_client' => 'Arkiver kunde',
    'delete_client' => 'Slett kunde',
    'archive_payment' => 'Arkiver betaling',
    'delete_payment' => 'Slett betaling',
    'archive_credit' => 'Arkiver kredit',
    'delete_credit' => 'Slett kredit',
    'show_archived_deleted' => 'Vis slettet/arkivert',
    'filter' => 'Filter',
    'new_client' => 'Ny Kunde',
    'new_invoice' => 'Ny faktura',
    'new_payment' => 'Oppgi Betaling',
    'new_credit' => 'Oppgi Kredit',
    'contact' => 'Kontakt',
    'date_created' => 'Dato Opprettet',
    'last_login' => 'Siste Pålogging',
    'balance' => 'Balanse',
    'action' => 'Handling',
    'status' => 'Status',
    'invoice_total' => 'Totalbeløp',
    'frequency' => 'Frekvens',
    'range' => 'Periode',
    'start_date' => 'Startdato',
    'end_date' => 'Sluttdato',
    'transaction_reference' => 'Transaksjonsreferanse',
    'method' => 'Betalingsmåte',
    'payment_amount' => 'Beløp',
    'payment_date' => 'Betalingsdato',
    'credit_amount' => 'Kreditbeløp',
    'credit_balance' => 'Kreditsaldo',
    'credit_date' => 'Kreditdato',
    'empty_table' => 'Ingen data er tilgjengelige i tabellen',
    'select' => 'Velg',
    'edit_client' => 'Rediger Kunde',
    'edit_invoice' => 'Rediger faktura',
    'create_invoice' => 'Opprett faktura',
    'enter_credit' => 'Oppgi Kredit',
    'last_logged_in' => 'Sist pålogget',
    'details' => 'Detaljer',
    'standing' => 'Stående',
    'credit' => 'Kredit',
    'activity' => 'Aktivitet',
    'date' => 'Dato',
    'message' => 'Beskjed',
    'adjustment' => 'Justering',
    'are_you_sure' => 'Er du sikker?',
    'payment_type_id' => 'Betalingsmetode',
    'amount' => 'Beløp',
    'work_email' => 'E-post',
    'language_id' => 'Språk',
    'timezone_id' => 'Tidssone',
    'date_format_id' => 'Dato format',
    'datetime_format_id' => 'Dato/Tidsformat',
    'users' => 'Brukere',
    'localization' => 'Regioninnstillinger',
    'remove_logo' => 'Fjern logo',
    'logo_help' => 'Støttede filtyper: JPEG, GIF og PNG',
    'payment_gateway' => 'Betalingsløsning',
    'gateway_id' => 'Tilbyder',
    'email_notifications' => 'Varsel via e-post',
    'email_sent' => 'Varsle når en faktura er <b>sendt</b>',
    'email_viewed' => 'Varsle når en faktura er <b>sett</b>',
    'email_paid' => 'Varsle når en faktura er <b>betalt</b>',
    'site_updates' => 'Side Oppdateringer',
    'custom_messages' => 'Tilpassede Meldinger',
    'default_email_footer' => 'Sett standard <b>e-post-signatur</b>',
    'select_file' => 'Vennligst velg en fil',
    'first_row_headers' => 'Bruk første rad som overskrifter',
    'column' => 'Kolonne',
    'sample' => 'Eksempel',
    'import_to' => 'Importer til',
    'client_will_create' => 'kunde vil bli opprettet',
    'clients_will_create' => 'kunder vil bli opprettet',
    'email_settings' => 'E-post-innstillinger',
    'client_view_styling' => 'Kundevisningsstil',
    'pdf_email_attachment' => 'Legg ved PDF',
    'custom_css' => 'Egendefinert CSS',
    'import_clients' => 'Importer Kundedata',
    'csv_file' => 'Velg CSV-fil',
    'export_clients' => 'Eksporter Kundedata',
    'created_client' => 'Opprettet kunde',
    'created_clients' => 'Opprettet :count kunder',
    'updated_settings' => 'Innstillinger oppdatert',
    'removed_logo' => 'Logoen ble fjernet',
    'sent_message' => 'Melding ble sendt',
    'invoice_error' => 'Vennligst sørg for å velge en kunde og rette eventuelle feil',
    'limit_clients' => 'Dessverre, dette vil overstige grensen på :count kunder',
    'payment_error' => 'Det oppstod en feil under din betaling. Vennligst prøv igjen senere.',
    'registration_required' => 'Vennligst registrer deg for å sende e-postfaktura',
    'confirmation_required' => 'Please confirm your email address, :link to resend the confirmation email.',
    'updated_client' => 'Oppdaterte kunde',
    'archived_client' => 'Arkiverte kunde',
    'archived_clients' => 'Arkiverte :count kunder',
    'deleted_client' => 'Slettet kunde',
    'deleted_clients' => 'Slettet :count kunder',
    'updated_invoice' => 'Faktura oppdatert',
    'created_invoice' => 'Faktura opprettet',
    'cloned_invoice' => 'Faktura kopiert',
    'emailed_invoice' => 'E-postfaktura sendt',
    'and_created_client' => 'og opprettet kunde',
    'archived_invoice' => 'Faktura arkivert',
    'archived_invoices' => 'Fakturaer arkivert',
    'deleted_invoice' => 'Faktura slettet',
    'deleted_invoices' => 'Slettet :count fakturaer',
    'created_payment' => 'Betaling opprettet',
    'created_payments' => 'Opprettet :count betaling(er)',
    'archived_payment' => 'Betaling arkivert',
    'archived_payments' => 'Arkiverte :count betalinger',
    'deleted_payment' => 'Betaling slettet',
    'deleted_payments' => 'Slettet :count betalinger',
    'applied_payment' => 'Betaling lagret',
    'created_credit' => 'Kredit opprettet',
    'archived_credit' => 'Kredit arkivert',
    'archived_credits' => 'Arkiverte :count krediter',
    'deleted_credit' => 'Kredit slettet',
    'deleted_credits' => 'Slettet :count krediter',
    'imported_file' => 'Importering av fil ble vellykket',
    'updated_vendor' => 'Oppdaterte leverandør',
    'created_vendor' => 'Opprettet leverandør',
    'archived_vendor' => 'Arkiverte leverandør',
    'archived_vendors' => 'Arkiverte :count leverandører',
    'deleted_vendor' => 'Slettet leverandør',
    'deleted_vendors' => 'Slettet :count leverandører',
    'confirmation_subject' => 'Invoice Ninja-kontobekreftelse',
    'confirmation_header' => 'Kontobekreftelse',
    'confirmation_message' => 'Vennligst åpne lenken nedenfor for å bekrefte kontoen din.',
    'invoice_subject' => 'Ny faktura :number fra :account',
    'invoice_message' => 'Klikk linken under for denne fakturaen:',
    'payment_subject' => 'Betaling mottatt',
    'payment_message' => 'Takk for din betaling pålydende :amount.',
    'email_salutation' => 'Kjære :name,',
    'email_signature' => 'Med vennlig hilsen,',
    'email_from' => 'Invoice Ninja Gjengen',
    'invoice_link_message' => 'Hvis du vil se fakturaen, klikk på lenken under:',
    'notification_invoice_paid_subject' => 'Faktura :invoice betalt av :client',
    'notification_invoice_sent_subject' => 'Faktura :invoice sendt til :client',
    'notification_invoice_viewed_subject' => 'Faktura :invoice sett av :client',
    'notification_invoice_paid' => 'En betaling pålydende :amount ble gjort av :client for faktura :invoice.',
    'notification_invoice_sent' => 'E-post har blitt sendt til :client - Faktura :invoice pålydende :amount.',
    'notification_invoice_viewed' => ':client har nå sett faktura :invoice pålydende :amount.',
    'reset_password' => 'Du kan nullstille ditt passord ved å besøke følgende lenke:',
    'secure_payment' => 'Sikker betaling',
    'card_number' => 'Kortnummer',
    'expiration_month' => 'Utløpsdato',
    'expiration_year' => 'Utløpsår',
    'cvv' => 'CVV',
    'logout' => 'Logg ut',
    'sign_up_to_save' => 'Registrer deg for å lagre arbeidet ditt',
    'agree_to_terms' => 'I agree to the :terms',
    'terms_of_service' => 'vilkår for bruk',
    'email_taken' => 'Epost-adressen er allerede registrert',
    'working' => 'Jobber',
    'success' => 'Suksess',
    'success_message' => 'Du har nå blitt registrert. Vennligst gå inn på lenken som du har mottatt i e-postbekreftelsen for å bekrefte e-postadressen.',
    'erase_data' => 'Din konto er ikke registrert, dette vil slette dataene permanent.',
    'password' => 'Passord',
    'pro_plan_product' => 'Pro Plan',
    'pro_plan_success' => 'Takk for at du valgte Invoice Ninja\'s Pro plan!<p/>&nbsp;<br/>
                          <b>Neste steg</b><p/>en betalbar faktura er sendt til e-postadressen
                          som er tilknyttet kontoen din. For å låse opp alle de utrolige
                          Pro-funksjonene, kan du følge instruksjonene på fakturaen til å
                          betale for et år med Pro-nivå funksjoner.<p/>
                          Finner du ikke fakturaen? Trenger du mer hjelp? Vi hjelper deg gjerne om det skulle være noe
                          -- kontakt oss på contact@invoiceninja.com',
    'unsaved_changes' => 'Du har ulagrede endringer',
    'custom_fields' => 'Egendefinerte felt',
    'company_fields' => 'Firmaets felt',
    'client_fields' => 'Kundens felt',
    'field_label' => 'Felt etikett',
    'field_value' => 'Feltets verdi',
    'edit' => 'Endre',
    'set_name' => 'Sett ditt firmanavn',
    'view_as_recipient' => 'Vis som mottaker',
    'product_library' => 'Produktbibliotek',
    'product' => 'Produkt',
    'products' => 'Produkter',
    'fill_products' => 'Automatisk-utfyll produkter',
    'fill_products_help' => 'Valg av produkt vil automatisk fylle ut <b>beskrivelse og kostnaden</b>',
    'update_products' => 'Automatisk oppdater produkter',
    'update_products_help' => 'Å endre en faktura vil automatisk <b>oppdatere produktbilioteket</b>',
    'create_product' => 'Lag nytt produkt',
    'edit_product' => 'Endre produkt',
    'archive_product' => 'Arkiver produkt',
    'updated_product' => 'Produkt oppdatert',
    'created_product' => 'Produkt lagret',
    'archived_product' => 'Produkt arkivert',
    'pro_plan_custom_fields' => ':link for å aktivere egendefinerte felt ved å delta i Pro Plan',
    'advanced_settings' => 'Avanserte innstillinger',
    'pro_plan_advanced_settings' => ':link for å aktivere avanserte innstillinger ved å delta i en Pro Plan',
    'invoice_design' => 'Fakturadesign',
    'specify_colors' => 'Egendefinerte farger',
    'specify_colors_label' => 'Velg farger som brukes i fakturaen',
    'chart_builder' => 'Diagram bygger',
    'ninja_email_footer' => 'Laget av :site | Opprett. Send. Få Betalt. ',
    'go_pro' => 'Velg Pro',
    'quote' => 'Pristilbud',
    'quotes' => 'Pristilbud',
    'quote_number' => 'Tilbudsnummer',
    'quote_number_short' => 'Tilbud #',
    'quote_date' => 'Tilbudsdato',
    'quote_total' => 'Tilbud totalt',
    'your_quote' => 'Ditt tilbud',
    'total' => 'Totalt',
    'clone' => 'Kopier',
    'new_quote' => 'Nytt tilbud',
    'create_quote' => 'Lag tilbud',
    'edit_quote' => 'Endre tilbud',
    'archive_quote' => 'Arkiver tilbud',
    'delete_quote' => 'Slett tilbud',
    'save_quote' => 'Lagre tilbud',
    'email_quote' => 'Send tilbudet som E-post',
    'clone_quote' => 'Kopier som tilbud',
    'convert_to_invoice' => 'Konverter til en faktura',
    'view_invoice' => 'Se faktura',
    'view_client' => 'Vis Kunde',
    'view_quote' => 'Se tilbud',
    'updated_quote' => 'Tilbud oppdatert',
    'created_quote' => 'Tilbud opprettet',
    'cloned_quote' => 'Tilbud kopiert',
    'emailed_quote' => 'Tilbud sendt som e-post',
    'archived_quote' => 'Tilbud arkivert',
    'archived_quotes' => 'Arkiverte :count tilbud',
    'deleted_quote' => 'Tilbud slettet',
    'deleted_quotes' => 'Slettet :count tilbud',
    'converted_to_invoice' => 'Tilbud konvertert til faktura',
    'quote_subject' => 'Nytt tilbud :number fra :account',
    'quote_message' => 'For å se ditt tilbud pålydende :amount, klikk lenken nedenfor.',
    'quote_link_message' => 'Hvis du vil se din kundes tilbud, klikk på lenken under:',
    'notification_quote_sent_subject' => 'Tilbud :invoice sendt til :client',
    'notification_quote_viewed_subject' => 'Tilbudet :invoice er nå sett av :client',
    'notification_quote_sent' => 'Kunden :client ble sendt tilbud :invoice på :amount.',
    'notification_quote_viewed' => 'Kunden :client har nå sett tilbud :invoice på :amount.',
    'session_expired' => 'Økten er utløpt.',
    'invoice_fields' => 'Faktura felt',
    'invoice_options' => 'Faktura alternativer',
    'hide_paid_to_date' => 'Skjul delbetalinger',
    'hide_paid_to_date_help' => 'Bare vis delbetalinger om det har forekommet en delbetaling.',
    'charge_taxes' => 'Inkluder skatt',
    'user_management' => 'Brukerhåndtering',
    'add_user' => 'Legg til bruker',
    'send_invite' => 'Send invitasjon',
    'sent_invite' => 'Invitasjon sendt',
    'updated_user' => 'Bruker oppdatert',
    'invitation_message' => 'Du har blitt invitert av :invitor. ',
    'register_to_add_user' => 'Vennligst registrer deg for å legge til en bruker',
    'user_state' => 'Status',
    'edit_user' => 'Endre bruker',
    'delete_user' => 'Slett bruker',
    'active' => 'Aktiv',
    'pending' => 'Avventer',
    'deleted_user' => 'Bruker slettet',
    'confirm_email_invoice' => 'Er du sikker på at du ønsker å sende denne fakturaen som e-post?',
    'confirm_email_quote' => 'Er du sikker på at du ønsker å sende dette tilbudet som e-post?',
    'confirm_recurring_email_invoice' => 'Er du sikker på at du ønsker denne fakturaen send som e-post?',
    'confirm_recurring_email_invoice_not_sent' => 'Are you sure you want to start the recurrence?',
    'cancel_account' => 'Kanseler Konto',
    'cancel_account_message' => 'Advarsel: Dette vil permanent slette kontoen din, du kan ikke angre.',
    'go_back' => 'Gå Tilbake',
    'data_visualizations' => 'Datavisualiseringer',
    'sample_data' => 'Eksempel data vist',
    'hide' => 'Skjul',
    'new_version_available' => 'En ny versjon av :releases_link er tilgjengelig. Du kjører v:user_version, siste versjon er v:latest_version',
    'invoice_settings' => 'Fakturainnstillinger',
    'invoice_number_prefix' => 'Fakturanummer-prefiks',
    'invoice_number_counter' => 'Fakturanummer-teller',
    'quote_number_prefix' => 'Tilbudsnummer-prefiks',
    'quote_number_counter' => 'Tilbudsnummer-teller',
    'share_invoice_counter' => 'Del faktura teller',
    'invoice_issued_to' => 'Faktura sendt til',
    'invalid_counter' => 'For å forhindre en mulig konflikt, sett et faktura eller tilbuds nummmer prefiks',
    'mark_sent' => 'Merk som Sendt',
    'gateway_help_1' => ':link for å lage en konto for Authorize.net.',
    'gateway_help_2' => ':link for å lage en konto for Authorize.net.',
    'gateway_help_17' => ':link for å få din PayPal API signatur.',
    'gateway_help_27' => ':link to sign up for 2Checkout.com. To ensure payments are tracked set :complete_link as the redirect URL under Account > Site Management in the 2Checkout portal.',
    'gateway_help_60' => ':link for og opprette en WePay konto',
    'more_designs' => 'Flere design',
    'more_designs_title' => 'Flere Faktura Design',
    'more_designs_cloud_header' => 'Gå Pro for flere faktura design',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Kjøp',
    'bought_designs' => 'Det ble suksessfullt lagt til flere design',
    'sent' => 'Sendt',
    'vat_number' => 'MVA-nummer',
    'timesheets' => 'Tidsskjemaer',
    'payment_title' => 'Oppgi Din Faktura Adresse og Betalingskort informasjon',
    'payment_cvv' => '*This is the 3-4 digit number on the back of your card',
    'payment_footer1' => '*Faktura adressen må være lik adressen assosiert med betalingskortet.',
    'payment_footer2' => '*Vennligst klikk "BETAL NÅ" kun en gang - transaksjonen kan ta opp til 1 minutt å prosessere.',
    'id_number' => 'Id nummer',
    'white_label_link' => 'Reklamefri',
    'white_label_header' => 'Reklamefri',
    'bought_white_label' => 'Du har suksessfullt aktivert din reklamefrie lisens.',
    'white_labeled' => 'Reklamefrie',
    'restore' => 'Gjenopprette',
    'restore_invoice' => 'Gjenopprette Faktura',
    'restore_quote' => 'Gjenopprette Tilbud',
    'restore_client' => 'Gjenopprett Kunde',
    'restore_credit' => 'Gjenopprett Kredit',
    'restore_payment' => 'Gjenopprette Betaling',
    'restored_invoice' => 'Suksessfullt gjenopprettet faktura',
    'restored_quote' => 'Suksessfullt gjenopprettet tilbud',
    'restored_client' => 'Gjenopprettet kunde',
    'restored_payment' => 'Suksessfullt gjenopprettet betaling',
    'restored_credit' => 'Suksessfullt gjenopprettet kredit',
    'reason_for_canceling' => 'Hjelp oss å forbedre vår side ved å fortelle oss hvorfor du forlater oss.',
    'discount_percent' => 'Prosent',
    'discount_amount' => 'Beløp',
    'invoice_history' => 'Faktura Historikk',
    'quote_history' => 'Tilbuds Historikk',
    'current_version' => 'Nåværende versjon',
    'select_version' => 'Velg versjon',
    'view_history' => 'Vis Historikk',
    'edit_payment' => 'Rediger Betaling',
    'updated_payment' => 'Suksessfullt oppdatert betaling',
    'deleted' => 'Slettet',
    'restore_user' => 'Gjenopprett Bruker',
    'restored_user' => 'Suksessfullt gjenopprettet bruker',
    'show_deleted_users' => 'Vis slettede brukere',
    'email_templates' => 'E-post-maler',
    'invoice_email' => 'Faktura-e-post',
    'payment_email' => 'Betalings-e-post',
    'quote_email' => 'Tilbuds-e-post',
    'reset_all' => 'Tilbakebestill Alt',
    'approve' => 'Godkjenn',
    'token_billing_type_id' => 'Token-fakturering',
    'token_billing_help' => 'Store payment details with WePay, Stripe, Braintree or GoCardless.',
    'token_billing_1' => 'Deaktivert',
    'token_billing_2' => 'Valgfritt - valgboks er vist, men ikke valgt',
    'token_billing_3' => 'Aktivert - valgboks er vist og valgt',
    'token_billing_4' => 'Alltid',
    'token_billing_checkbox' => 'Lagre bankkort-detaljer',
    'view_in_gateway' => 'Vis i :gateway',
    'use_card_on_file' => 'Bruk lagret kort',
    'edit_payment_details' => 'Rediger betalingsdetaljer',
    'token_billing' => 'Lagre kortdetaljer',
    'token_billing_secure' => 'Dataene er trygt lagret av :link',
    'support' => 'Brukerstøtte',
    'contact_information' => 'Kontaktinformasjon',
    '256_encryption' => '256-Bit Kryptering',
    'amount_due' => 'Skyldig beløp',
    'billing_address' => 'Fakturerings Adresse',
    'billing_method' => 'Fakturerings Metode',
    'order_overview' => 'Bestillings oversikt',
    'match_address' => '*Adressen må være lik adressen med assosiert betalingskort',
    'click_once' => '*Vennligst klikk "BETAL NÅ" kun en gang - transaksjonen kan ta opp til 1 minutt å prosessere.',
    'invoice_footer' => 'Faktura Bunntekst',
    'save_as_default_footer' => 'Lagre som standard bunntekst',
    'token_management' => 'Token-organisering',
    'tokens' => 'Tokens',
    'add_token' => 'Legg til token',
    'show_deleted_tokens' => 'Vis slettede tokens',
    'deleted_token' => 'Suksessfullt slettet token',
    'created_token' => 'Opprettet token',
    'updated_token' => 'Oppdaterte token',
    'edit_token' => 'Rediger Token',
    'delete_token' => 'Slett Token',
    'token' => 'Token',
    'add_gateway' => 'Legg til Tilbyder',
    'delete_gateway' => 'Slett Tilbyder',
    'edit_gateway' => 'Rediger Tilbyder',
    'updated_gateway' => 'Suksessfullt oppdatert tilbyder',
    'created_gateway' => 'Suksessfullt opprettet tilbyder',
    'deleted_gateway' => 'Suksessfullt slettet tilbyder',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Betalingskort',
    'change_password' => 'Skift passord',
    'current_password' => 'Nåværende passord',
    'new_password' => 'Nytt passord',
    'confirm_password' => 'Bekreft passord',
    'password_error_incorrect' => 'Nåværende passord er ikke riktig.',
    'password_error_invalid' => 'Det nye passordet er ikke godkjent.',
    'updated_password' => 'Suksessfullt oppdatert passord',
    'api_tokens' => 'API-tokens',
    'users_and_tokens' => 'Brukere & Tokens',
    'account_login' => 'Kontoinnlogging',
    'recover_password' => 'Gjenopprett ditt passord',
    'forgot_password' => 'Glemt ditt passord?',
    'email_address' => 'E-post-adresse',
    'lets_go' => 'La oss fortsette',
    'password_recovery' => 'Passord gjenoppretting',
    'send_email' => 'Send e-post',
    'set_password' => 'Sett Passord',
    'converted' => 'Konvertert',
    'email_approved' => 'Send meg en e-post når tilbudet er <b>godkjent</b>',
    'notification_quote_approved_subject' => 'Tilbud :invoice ble godkjent av :client',
    'notification_quote_approved' => 'Kunden :client godkjente tilbud :invoice på :amount.',
    'resend_confirmation' => 'Send e-postbekreftelse på nytt',
    'confirmation_resent' => 'E-postbekreftelsen ble sendt på nytt',
    'gateway_help_42' => ':link for å lage en konto hos BitPay.<br/>Info: bruk en Legacy API-nøkkel, ikke en API-token.',
    'payment_type_credit_card' => 'Bankkort',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Kunnskapsbase',
    'partial' => 'Delvis/Depositum',
    'partial_remaining' => ':delvis av :balance',
    'more_fields' => 'Flere Felt',
    'less_fields' => 'Færre Felt',
    'client_name' => 'Kundenavn',
    'pdf_settings' => 'PDF-innstillinger',
    'product_settings' => 'Produkt-innstillinger',
    'auto_wrap' => 'Automatisk Linjebryting',
    'duplicate_post' => 'Advarsel: forrige side ble sendt inn to ganger. Den andre innsendingen har derfor blitt ignorert.',
    'view_documentation' => 'Vis Dokumentasjon',
    'app_title' => 'Gratis Åpen Kildekode Internett-fakturering',
    'app_description' => 'Invoice Ninja er en gratis, åpen kildekode løsning for fakturaer og fakturering av kunder. Med Invoice Ninja, kan du enkelt bygge og sende vakre fakturaer fra alle enheter som har tilgang til nettet. Dine kunder kan skrive ut fakturaer, laste dem ned som pdf-filer og selv betale deg på internett fra systemet.',
    'rows' => 'rader',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Subdomene',
    'provide_name_or_email' => 'Vennligst oppgi et kontaktnavn eller e-post adresse',
    'charts_and_reports' => 'Diagrammer & Rapporter',
    'chart' => 'Diagram',
    'report' => 'Rapport',
    'group_by' => 'Grupper etter',
    'paid' => 'Betalt',
    'enable_report' => 'Rapport',
    'enable_chart' => 'Diagram',
    'totals' => 'Totaler',
    'run' => 'Kjør',
    'export' => 'Eksporter',
    'documentation' => 'Dokumentasjon',
    'zapier' => 'Zapier',
    'recurring' => 'Gjentakende',
    'last_invoice_sent' => 'Siste faktura sendt :date',
    'processed_updates' => 'Suksessfullt fullført oppdatering',
    'tasks' => 'Oppgaver',
    'new_task' => 'Ny Oppgave',
    'start_time' => 'Starttid',
    'created_task' => 'Suksessfullt opprettet oppgave',
    'updated_task' => 'Suksessfullt oppdatert oppgave',
    'edit_task' => 'Rediger Oppgave',
    'clone_task' => 'Kopier oppgaven',
    'archive_task' => 'Arkiver Oppgave',
    'restore_task' => 'Gjennopprett Oppgave',
    'delete_task' => 'Slett Oppgave',
    'stop_task' => 'Stopp Oppgave',
    'time' => 'Tid',
    'start' => 'Start',
    'stop' => 'Stopp',
    'now' => 'Nå',
    'timer' => 'Tidtaker',
    'manual' => 'Manuell',
    'date_and_time' => 'Dato & Tid',
    'second' => 'sekund',
    'seconds' => 'sekunder',
    'minute' => 'minutt',
    'minutes' => 'minutter',
    'hour' => 'time',
    'hours' => 'timer',
    'task_details' => 'Oppgavedetaljer',
    'duration' => 'Varighet',
    'time_log' => 'Time Log',
    'end_time' => 'Sluttid',
    'end' => 'Slutt',
    'invoiced' => 'Fakturert',
    'logged' => 'Logget',
    'running' => 'Løpende',
    'task_error_multiple_clients' => 'Oppgaver kan ikke tilhøre andre kunder',
    'task_error_running' => 'Vennligst stopp løpende oppgaver først',
    'task_error_invoiced' => 'Oppgavene har allerede blitt fakturert',
    'restored_task' => 'Gjenopprettet oppgave',
    'archived_task' => 'Arkiverte oppgave',
    'archived_tasks' => 'Arkiverte :count oppgaver',
    'deleted_task' => 'Slettet oppgave',
    'deleted_tasks' => 'Slettet :count oppgaver',
    'create_task' => 'Opprett Oppgave',
    'stopped_task' => 'Suksessfullt stoppet oppgave',
    'invoice_task' => 'Fakturer Oppgave',
    'invoice_labels' => 'Faktureringsetiketter',
    'prefix' => 'Prefiks',
    'counter' => 'Teller',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link for å lage en konto hos Dwolla.<br/>Info: fjern bindestreker fra Destinasjons/Dwolla IDen',
    'partial_value' => 'Må være større enn null og mindre enn totalen',
    'more_actions' => 'Flere Valg',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Oppgrader Nå!',
    'pro_plan_feature1' => 'Opprett Ubegrensett Antall Kunder',
    'pro_plan_feature2' => 'Tilgang til 10 Vakre Faktura-maler',
    'pro_plan_feature3' => 'Tilpasset nettadresse - "DittFirma.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Fjern "Laget av Invoice Ninja"',
    'pro_plan_feature5' => 'Flerbruker Tilgang & Aktivitets Sporing',
    'pro_plan_feature6' => 'Lag Tilbud & Proforma Fakturaer',
    'pro_plan_feature7' => 'Modifiser felttitteler og nummerering på fakturaer',
    'pro_plan_feature8' => 'Mulighet til å legge ved PDF-er i e-post til kunder',
    'resume' => 'Gjenoppta',
    'break_duration' => 'Pause',
    'edit_details' => 'Rediger Detaljer',
    'work' => 'Arbeid',
    'timezone_unset' => 'Vennligst :link for å sette din tidssone',
    'click_here' => 'klikk her',
    'email_receipt' => 'Send betalingskvittering som e-post til kunden',
    'created_payment_emailed_client' => 'Opprettet betaling og sendte e-post til kunden',
    'add_company' => 'Legg til Firma',
    'untitled' => 'Uten navn',
    'new_company' => 'Nytt Firma',
    'associated_accounts' => 'Suksessfullt lenket kontoer',
    'unlinked_account' => 'Suksessfullt frakoblet kontoer',
    'login' => 'Logg inn',
    'or' => 'eller',
    'email_error' => 'Det oppstod et problem med utsending av e-posten',
    'confirm_recurring_timing' => 'Info: e-poster er sendt på begynnelsen av timen.',
    'confirm_recurring_timing_not_sent' => 'Note: invoices are created at the start of the hour.',
    'payment_terms_help' => 'Angir standard <b>fakturaforfall</b>',
    'unlink_account' => 'Frakoble Konto',
    'unlink' => 'Frakoble',
    'show_address' => 'Vis Adresse',
    'show_address_help' => 'Krev at kunden oppgir fakturaadresse',
    'update_address' => 'Oppdater Adresse',
    'update_address_help' => 'Oppdater kundens adresse med oppgitte detaljer',
    'times' => 'Tider',
    'set_now' => 'Sett til nå',
    'dark_mode' => 'Mørk Modus',
    'dark_mode_help' => 'Bruk en mørk bakgrunn for sidefelt',
    'add_to_invoice' => 'Legg til på faktura :invoice',
    'create_new_invoice' => 'Lag ny faktura',
    'task_errors' => 'Vennligst rett alle overlappende tider',
    'from' => 'Fra',
    'to' => 'Til',
    'font_size' => 'Skriftstørrelse',
    'primary_color' => 'Primærfarge',
    'secondary_color' => 'Sekundær farge',
    'customize_design' => 'Modifiser Design',
    'content' => 'Innhold',
    'styles' => 'Stiler',
    'defaults' => 'Standarder',
    'margins' => 'Marginer',
    'header' => 'Header',
    'footer' => 'Bunntekst',
    'custom' => 'Egendefiner',
    'invoice_to' => 'Fakturer til',
    'invoice_no' => 'Faktura Nr.',
    'quote_no' => 'Tilbudsnr.',
    'recent_payments' => 'Nylige Betalinger ',
    'outstanding' => 'Utestående',
    'manage_companies' => 'Administrer Firmaer',
    'total_revenue' => 'Sum omsetning',
    'current_user' => 'Nåværende Bruker',
    'new_recurring_invoice' => 'Ny Gjentakende Faktura',
    'recurring_invoice' => 'Gjentakende Faktura',
    'new_recurring_quote' => 'New Recurring Quote',
    'recurring_quote' => 'Recurring Quote',
    'recurring_too_soon' => 'Det er for tidlig å lage neste gjentakende faktura, den er planlagt for :date',
    'created_by_invoice' => 'Laget av :invoice',
    'primary_user' => 'Hovedbruker',
    'help' => 'Hjelp',
    'customize_help' => '<p>We use :pdfmake_link to define the invoice designs declaratively. The pdfmake :playground_link provides a great way to see the library in action.</p>
                        <p>If you need help figuring something out post a question to our :forum_link with the design you\'re using.</p>',
    'playground' => 'lekeplass',
    'support_forum' => 'support forum',
    'invoice_due_date' => 'Forfallsdato',
    'quote_due_date' => 'Gyldig til',
    'valid_until' => 'Gyldig til',
    'reset_terms' => 'Tilbakestill vilkår',
    'reset_footer' => 'Tilbakestill bunntekst',
    'invoice_sent' => ':count faktura sendt',
    'invoices_sent' => ':count fakturaer sendt',
    'status_draft' => 'Kladd',
    'status_sent' => 'Sendt',
    'status_viewed' => 'Vist',
    'status_partial' => 'Delvis',
    'status_paid' => 'Betalt',
    'status_unpaid' => 'Ubetalt',
    'status_all' => 'Alle',
    'show_line_item_tax' => 'Vis <b> linje element skatter på linje</b>',
    'iframe_url' => 'Nettside',
    'iframe_url_help1' => 'Kopier følgende kode til en side på din nettside.',
    'iframe_url_help2' => 'Du kan teste funksjonen ved å klikke \'Vis som mottager\' for en faktura.',
    'auto_bill' => 'Auto Fakturer',
    'military_time' => '24 Timers Tid',
    'last_sent' => 'Sist Sendt',
    'reminder_emails' => 'Påminnelses-e-poster',
    'quote_reminder_emails' => 'Quote Reminder Emails',
    'templates_and_reminders' => 'Design & Påminnelser',
    'subject' => 'Emne',
    'body' => 'Body',
    'first_reminder' => 'Første Påminnelse',
    'second_reminder' => 'Andre Påminnelse',
    'third_reminder' => 'Tredje Påminnelse',
    'num_days_reminder' => 'Dager etter forfall ',
    'reminder_subject' => 'Påminnelse: Faktura :invoice fra :account',
    'reset' => 'Nullstill',
    'invoice_not_found' => 'Ønsket faktura er ikke tilgjengelig',
    'referral_program' => 'Henvisningsprogram',
    'referral_code' => 'Henvisnings-URL',
    'last_sent_on' => 'Sendt Sist: :date',
    'page_expire' => 'Denne siden vil utløpe snart, :click_here for å fortsette å arbeide',
    'upcoming_quotes' => 'Oppkommende Tilbud',
    'expired_quotes' => 'Utløpte Tilbud',
    'sign_up_using' => 'Meld deg på ved å bruke',
    'invalid_credentials' => 'Disse kredentialene samsvarer ikke med våre opplysninger',
    'show_all_options' => 'Vis alle alternativene',
    'user_details' => 'Brukerdetaljer',
    'oneclick_login' => 'Connected Account',
    'disable' => 'Deaktiver',
    'invoice_quote_number' => 'Faktura- og tilbudsnummer',
    'invoice_charges' => 'Fakturatillegg',
    'notification_invoice_bounced' => 'Vi klarte ikke å levere Faktura :invoice til :contact.',
    'notification_invoice_bounced_subject' => 'Klarte ikke å levere Faktura :invoice',
    'notification_quote_bounced' => 'Vi klarte ikke å levere Tilbud :invoice til :contact.',
    'notification_quote_bounced_subject' => 'Klarte ikke å levere Tilbud :invoice',
    'custom_invoice_link' => 'Tilpasset Faktura Lenke',
    'total_invoiced' => 'Totalt Fakturert',
    'open_balance' => 'Åpen Balanse',
    'verify_email' => 'Vennligst besøk lenken i e-posten for kontobekreftelse for å bekrefte din e-postadresse.',
    'basic_settings' => 'Grunnleggende Innstillinger',
    'pro' => 'Pro',
    'gateways' => 'Betalingstilbydere',
    'next_send_on' => 'Send Neste: :date',
    'no_longer_running' => 'Denne fakturaen er ikke planlagt for kjøring',
    'general_settings' => 'Systeminnstillinger',
    'customize' => 'Tilpass',
    'oneclick_login_help' => 'Koble til en konto for å logge inn uten et passord',
    'referral_code_help' => 'Tjen penger ved å dele appen vår på internett',
    'enable_with_stripe' => 'Aktiver | Krever Stripe',
    'tax_settings' => 'Skatteinnstillinger',
    'create_tax_rate' => 'Legg Til Skattesats',
    'updated_tax_rate' => 'Suksessfullt oppdatert skattesats',
    'created_tax_rate' => 'Suksessfullt opprettet skattesats',
    'edit_tax_rate' => 'Rediger skattesats',
    'archive_tax_rate' => 'Arkiver skattesats',
    'archived_tax_rate' => 'Suksessfullt arkivert skattesatsen',
    'default_tax_rate_id' => 'Standard skattesats',
    'tax_rate' => 'Skattesats',
    'recurring_hour' => 'Gjentakende Time',
    'pattern' => 'Mønster',
    'pattern_help_title' => 'Mønster Hjelp',
    'pattern_help_1' => 'Opprett egendefinerte tall ved å angi et mønster',
    'pattern_help_2' => 'Tilgjengelige variabler:',
    'pattern_help_3' => 'For eksempel, :example vil bli konvertert til :value',
    'see_options' => 'Se alternativer',
    'invoice_counter' => 'Faktura Teller',
    'quote_counter' => 'Tilbuds Teller',
    'type' => 'Type',
    'activity_1' => ':user opprettet kunde :client',
    'activity_2' => ':user arkiverte kunde :client',
    'activity_3' => ':user slettet kunde :client',
    'activity_4' => ':user opprettet faktura :invoice',
    'activity_5' => ':user oppdaterte faktura :invoice',
    'activity_6' => ':user emailed invoice :invoice for :client to :contact',
    'activity_7' => ':contact viewed invoice :invoice for :client',
    'activity_8' => ':user arkiverte faktura :invoice',
    'activity_9' => ':user slettet faktura :invoice',
    'activity_10' => ':contact entered payment :payment for :payment_amount on invoice :invoice for :client',
    'activity_11' => ':user oppdaterte betaling :payment',
    'activity_12' => ':user arkiverte betaling :payment',
    'activity_13' => ':user slettet betaling :payment',
    'activity_14' => ':user la inn :credit kredit',
    'activity_15' => ':user oppdaterte :credit kredit',
    'activity_16' => ':user arkiverte :credit kredit',
    'activity_17' => ':user slettet :credit kredit',
    'activity_18' => ':user opprettet tilbud :quote',
    'activity_19' => ':user oppdaterte tilbud :quote',
    'activity_20' => ':user emailed quote :quote for :client to :contact',
    'activity_21' => ':contact viste tilbud :quote',
    'activity_22' => ':user arkiverte tilbud :quote',
    'activity_23' => ':user slettet tilbud :quote',
    'activity_24' => ':user gjenopprettet tilbud :quote',
    'activity_25' => ':user gjenopprettet faktura :invoice',
    'activity_26' => ':user gjenopprettet kunde :client',
    'activity_27' => ':user gjenopprettet betaling :payment',
    'activity_28' => ':user gjenopprettet :credit kredit',
    'activity_29' => ':contact approved quote :quote for :client',
    'activity_30' => ':user opprettet leverandør :vendor',
    'activity_31' => ':user arkiverte leverandør :vendor',
    'activity_32' => ':user slettet leverandør :vendor',
    'activity_33' => ':user gjenopprettet leverandør :vendor',
    'activity_34' => ':user opprettet utgift :expense',
    'activity_35' => ':user arkiverte utgift :expense',
    'activity_36' => ':user slettet utgift :expense',
    'activity_37' => ':user gjenopprettet utgift :expense',
    'activity_42' => ':user opprettet oppgave :task',
    'activity_43' => ':user oppdaterte oppgave :task',
    'activity_44' => ':user arkiverte oppgave :task',
    'activity_45' => ':user slettet oppgave :task',
    'activity_46' => ':user gjenopprettet oppgave :task',
    'activity_47' => ':user oppdaterte utgift :expense',
    'activity_48' => ':user updated ticket :ticket',
    'activity_49' => ':user closed ticket :ticket',
    'activity_50' => ':user merged ticket :ticket',
    'activity_51' => ':user split ticket :ticket',
    'activity_52' => ':contact opened ticket :ticket',
    'activity_53' => ':contact reopened ticket :ticket',
    'activity_54' => ':user reopened ticket :ticket',
    'activity_55' => ':contact replied ticket :ticket',
    'activity_56' => ':user viewed ticket :ticket',

    'payment' => 'Betaling',
    'system' => 'System',
    'signature' => 'E-post-signatur',
    'default_messages' => 'Standard Meldinger',
    'quote_terms' => 'Tilbuds Vilkår',
    'default_quote_terms' => 'Standard Tilbuds Vilkår',
    'default_invoice_terms' => 'Standard Faktura Vilkår',
    'default_invoice_footer' => 'Standard Faktura Bunntekst',
    'quote_footer' => 'Tilbud Bunntekst',
    'free' => 'Gratis',
    'quote_is_approved' => 'Successfully approved',
    'apply_credit' => 'Bruk Kredit',
    'system_settings' => 'Systeminnstillinger',
    'archive_token' => 'Arkiver Token',
    'archived_token' => 'Suksessfullt arkivert token',
    'archive_user' => 'Arkiver Bruker',
    'archived_user' => 'Suksessfullt arkivert bruker',
    'archive_account_gateway' => 'Delete Gateway',
    'archived_account_gateway' => 'Suksessfullt arkivert tilbyder',
    'archive_recurring_invoice' => 'Arkiver Gjentakende Faktura',
    'archived_recurring_invoice' => 'Suksessfullt arkivert gjentakende faktura',
    'delete_recurring_invoice' => 'Slett Gjentakende Faktura',
    'deleted_recurring_invoice' => 'Suksessfullt slettet gjentakende faktura',
    'restore_recurring_invoice' => 'Gjenopprett Gjentakende Faktura',
    'restored_recurring_invoice' => 'Suksessfullt gjenopprettet gjentakende faktura',
    'archive_recurring_quote' => 'Archive Recurring Quote',
    'archived_recurring_quote' => 'Successfully archived recurring quote',
    'delete_recurring_quote' => 'Delete Recurring Quote',
    'deleted_recurring_quote' => 'Successfully deleted recurring quote',
    'restore_recurring_quote' => 'Restore Recurring Quote',
    'restored_recurring_quote' => 'Successfully restored recurring quote',
    'archived' => 'Arkivert',
    'untitled_account' => 'Firma Uten Navn',
    'before' => 'Before',
    'after' => 'After',
    'reset_terms_help' => 'Reset to the default account terms',
    'reset_footer_help' => 'Reset to the default account footer',
    'export_data' => 'Export Data',
    'user' => 'User',
    'country' => 'Country',
    'include' => 'Include',
    'logo_too_large' => 'Your logo is :size, for better PDF performance we suggest uploading an image file less than 200KB',
    'import_freshbooks' => 'Import From FreshBooks',
    'import_data' => 'Import Data',
    'source' => 'Source',
    'csv' => 'CSV',
    'client_file' => 'Client File',
    'invoice_file' => 'Invoice File',
    'task_file' => 'Task File',
    'no_mapper' => 'No valid mapping for file',
    'invalid_csv_header' => 'Invalid CSV Header',
    'client_portal' => 'Kundeportal',
    'admin' => 'Admin',
    'disabled' => 'Disabled',
    'show_archived_users' => 'Vis arkiverte brukere',
    'notes' => 'Notater',
    'invoice_will_create' => 'faktura vil bli opprettet',
    'invoices_will_create' => 'invoices will be created',
    'failed_to_import' => 'The following records failed to import, they either already exist or are missing required fields.',
    'publishable_key' => 'Publishable Key',
    'secret_key' => 'Secret Key',
    'missing_publishable_key' => 'Set your Stripe publishable key for an improved checkout process',
    'email_design' => 'Email Design',
    'due_by' => 'Forfall ved :date',
    'enable_email_markup' => 'Enable Markup',
    'enable_email_markup_help' => 'Make it easier for your clients to pay you by adding schema.org markup to your emails.',
    'template_help_title' => 'Templates Help',
    'template_help_1' => 'Available variables:',
    'email_design_id' => 'E-poststil',
    'email_design_help' => 'Gjør e-postene dine mer profesjonelle med HTML-oppsett.',
    'plain' => 'Plain',
    'light' => 'Light',
    'dark' => 'Dark',
    'industry_help' => 'Used to provide comparisons against the averages of companies of similar size and industry.',
    'subdomain_help' => 'Sett subdomenet eller vis fakturaen på ditt eget nettsted.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the invoice number.',
    'quote_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the quote number.',
    'custom_client_fields_helps' => 'Legg til et felt når du oppretter en kunde, og vis etiketten og verdien på PDF-en.',
    'custom_account_fields_helps' => 'Add a label and value to the company details section of the PDF.',
    'custom_invoice_fields_helps' => 'Legg til et felt når du oppretter en faktura, og vis etiketten og verdien på PDF-en.',
    'custom_invoice_charges_helps' => 'Add a text input to the invoice create/edit page and include the charge in the invoice subtotals.',
    'token_expired' => 'Validation token was expired. Please try again.',
    'invoice_link' => 'Invoice Link',
    'button_confirmation_message' => 'Click to confirm your email address.',
    'confirm' => 'Confirm',
    'email_preferences' => 'Email Preferences',
    'created_invoices' => 'Successfully created :count invoice(s)',
    'next_invoice_number' => 'The next invoice number is :number.',
    'next_quote_number' => 'The next quote number is :number.',
    'days_before' => 'dager før',
    'days_after' => 'dager etter',
    'field_due_date' => 'forfallsdato',
    'field_invoice_date' => 'invoice date',
    'schedule' => 'Planlegg',
    'email_designs' => 'Email Designs',
    'assigned_when_sent' => 'Assigned when sent',
    'white_label_purchase_link' => 'Purchase a white label license',
    'expense' => 'Utgift',
    'expenses' => 'Utgifter',
    'new_expense' => 'Angi utgift',
    'enter_expense' => 'Angi Utgift',
    'vendors' => 'Leverandører',
    'new_vendor' => 'Ny Leverandør',
    'payment_terms_net' => 'Net',
    'vendor' => 'Leverandør',
    'edit_vendor' => 'Rediger Leverandør',
    'archive_vendor' => 'Arkiver Leverandør',
    'delete_vendor' => 'Slett Leverandør',
    'view_vendor' => 'Vis Leverandør',
    'deleted_expense' => 'Successfully deleted expense',
    'archived_expense' => 'Successfully archived expense',
    'deleted_expenses' => 'Slettet utgifter',
    'archived_expenses' => 'Arkiverte utgifter',
    'expense_amount' => 'Expense Amount',
    'expense_balance' => 'Expense Balance',
    'expense_date' => 'Utgiftsdato',
    'expense_should_be_invoiced' => 'Should this expense be invoiced?',
    'public_notes' => 'Offentlig notater',
    'invoice_amount' => 'Invoice Amount',
    'exchange_rate' => 'Exchange Rate',
    'yes' => 'Yes',
    'no' => 'No',
    'should_be_invoiced' => 'Should be invoiced',
    'view_expense' => 'View expense # :expense',
    'edit_expense' => 'Edit Expense',
    'archive_expense' => 'Arkiver Utgift',
    'delete_expense' => 'Delete Expense',
    'view_expense_num' => 'Expense # :expense',
    'updated_expense' => 'Successfully updated expense',
    'created_expense' => 'Successfully created expense',
    'enter_expense' => 'Angi Utgift',
    'view' => 'View',
    'restore_expense' => 'Restore Expense',
    'invoice_expense' => 'Invoice Expense',
    'expense_error_multiple_clients' => 'Utgiftene kan ikke tilhøre flere kunder',
    'expense_error_invoiced' => 'Expense has already been invoiced',
    'convert_currency' => 'Convert currency',
    'num_days' => 'Antall dager',
    'create_payment_term' => 'Create Payment Term',
    'edit_payment_terms' => 'Edit Payment Term',
    'edit_payment_term' => 'Edit Payment Term',
    'archive_payment_term' => 'Archive Payment Term',
    'recurring_due_dates' => 'Recurring Invoice Due Dates',
    'recurring_due_date_help' => '<p>Automatically sets a due date for the invoice.</p>
        <p>Invoices on a monthly or yearly cycle set to be due on or before the day they are created will be due the next month. Invoices set to be due on the 29th or 30th in months that don\'t have that day will be due the last day of the month.</p>
        <p>Invoices on a weekly cycle set to be due on the day of the week they are created will be due the next week.</p>
        <p>For example:</p>
        <ul>
          <li>Today is the 15th, due date is 1st of the month. The due date should likely be the 1st of the next month.</li>
          <li>Today is the 15th, due date is the last day of the month. The due date will be the last day of the this month.
    </li>
          <li>Today is the 15th, due date is the 15th day of the month. The due date will be the 15th day of <strong>next</strong> month.
    </li>
          <li>Today is the Friday, due date is the 1st Friday after. The due date will be next Friday, not today.
    </li>
        </ul>',
    'due' => 'Forfaller',
    'next_due_on' => 'Forfaller neste: :date',
    'use_client_terms' => 'Use client terms',
    'day_of_month' => ':ordinal dag i måned',
    'last_day_of_month' => 'Siste dag i måned',
    'day_of_week_after' => ':ordinal :day after',
    'sunday' => 'Søndag',
    'monday' => 'Mandag',
    'tuesday' => 'Tirsdag',
    'wednesday' => 'Onsdag',
    'thursday' => 'Torsdag',
    'friday' => 'Fredag',
    'saturday' => 'Lørdag',
    'header_font_id' => 'Header Font',
    'body_font_id' => 'Body Font',
    'color_font_help' => 'Note: the primary color and fonts are also used in the client portal and custom email designs.',
    'live_preview' => 'Live Preview',
    'invalid_mail_config' => 'Unable to send email, please check that the mail settings are correct.',
    'invoice_message_button' => 'To view your invoice for :amount, click the button below.',
    'quote_message_button' => 'To view your quote for :amount, click the button below.',
    'payment_message_button' => 'Thank you for your payment of :amount.',
    'payment_type_direct_debit' => 'Direct Debit',
    'bank_accounts' => 'Bankkort & Banker',
    'add_bank_account' => 'Legg til bankkonto',
    'setup_account' => 'Setup Account',
    'import_expenses' => 'Importer Utgifter',
    'bank_id' => 'Bank',
    'integration_type' => 'Integration Type',
    'updated_bank_account' => 'Oppdaterte bankkonto',
    'edit_bank_account' => 'Rediger Bankkonto',
    'archive_bank_account' => 'Arkiver Bankkonto',
    'archived_bank_account' => 'Arkiverte bankkonto',
    'created_bank_account' => 'Successfully created bank account',
    'validate_bank_account' => 'Validate Bank Account',
    'bank_password_help' => 'PS: Passordet ditt blir sendt sikkert og blir ikke lagret på våre servere.',
    'bank_password_warning' => 'Warning: your password may be transmitted in plain text, consider enabling HTTPS.',
    'username' => 'Brukernavn',
    'account_number' => 'Kontonummer',
    'account_name' => 'Kontonavn',
    'bank_account_error' => 'Failed to retrieve account details, please check your credentials.',
    'status_approved' => 'Godkjent',
    'quote_settings' => 'Tilbudsinnstillinger',
    'auto_convert_quote' => 'Auto Konverter',
    'auto_convert_quote_help' => 'Automatically convert a quote to an invoice when approved by a client.',
    'validate' => 'Valider',
    'info' => 'Info',
    'imported_expenses' => 'Opprettet :count_vendors leverandør(er) og :count_expenses utgift(er)',
    'iframe_url_help3' => 'Note: if you plan on accepting credit cards details we strongly recommend enabling HTTPS on your site.',
    'expense_error_multiple_currencies' => 'The expenses can\'t have different currencies.',
    'expense_error_mismatch_currencies' => 'The client\'s currency does not match the expense currency.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Header/Footer',
    'first_page' => 'Første side',
    'all_pages' => 'Alle sider',
    'last_page' => 'Siste side',
    'all_pages_header' => 'Show header on',
    'all_pages_footer' => 'Show footer on',
    'invoice_currency' => 'Fakturavaluta',
    'enable_https' => 'We strongly recommend using HTTPS to accept credit card details online.',
    'quote_issued_to' => ' Faktura sendt til ',
    'show_currency_code' => 'Valutakode',
    'free_year_message' => 'Din konto har blitt oppgradert til Pro-plan i ett år helt gratis.',
    'trial_message' => 'Your account will receive a free two week trial of our pro plan.',
    'trial_footer' => 'Din gratis Pro-plan prøveperiode varer :count flere dager, :link for å oppgradere nå.',
    'trial_footer_last_day' => 'Dette er den siste dagen i  Pro-plan prøveperioden , :link for å oppgradere nå.',
    'trial_call_to_action' => 'Start Free Trial',
    'trial_success' => 'Successfully enabled two week free pro plan trial',
    'overdue' => 'Forfalt',


    'white_label_text' => 'Kjøp ett års white-label-lisens for $:price for å fjerne Invoice Ninja branding fra fakturaer og kundeportal.',
    'user_email_footer' => 'For å justere varslingsinnstillingene vennligst besøk :link',
    'reset_password_footer' => 'Hvis du ikke ba om å få nullstillt ditt passord, vennligst kontakt kundeservice: :email',
    'limit_users' => 'Dessverre, vil dette overstige grensen på :limit brukere',
    'more_designs_self_host_header' => 'Få 6 flere design for bare $:price',
    'old_browser' => 'Please use a :link',
    'newer_browser' => 'nyere nettleser',
    'white_label_custom_css' => ':link for $:price to enable custom styling and help support our project.',
    'bank_accounts_help' => 'Connect a bank account to automatically import expenses and create vendors. Supports American Express and :link.',
    'us_banks' => '400+ US banks',

    'pro_plan_remove_logo' => ':link for å fjerne Invoice Ninja-logoen, oppgrader til en Pro Plan',
    'pro_plan_remove_logo_link' => 'Klikk her',
    'invitation_status_sent' => 'Sendt',
    'invitation_status_opened' => 'Åpnet',
    'invitation_status_viewed' => 'Vist',
    'email_error_inactive_client' => 'Emails can not be sent to inactive clients',
    'email_error_inactive_contact' => 'Emails can not be sent to inactive contacts',
    'email_error_inactive_invoice' => 'Emails can not be sent to inactive invoices',
    'email_error_inactive_proposal' => 'Email kan ikke sendes til inaktive tilbud',
    'email_error_user_unregistered' => 'Please register your account to send emails',
    'email_error_user_unconfirmed' => 'Please confirm your account to send emails',
    'email_error_invalid_contact_email' => 'Invalid contact email',

    'navigation' => 'Navigation',
    'list_invoices' => 'List Invoices',
    'list_clients' => 'List Clients',
    'list_quotes' => 'List Quotes',
    'list_tasks' => 'List Tasks',
    'list_expenses' => 'Liste Utgifter',
    'list_recurring_invoices' => 'List Recurring Invoices',
    'list_payments' => 'List Payments',
    'list_credits' => 'List Credits',
    'tax_name' => 'Skattenavn',
    'report_settings' => 'Rapportalternativer',
    'search_hotkey' => 'Søk etter faktura, kunde, vare.. ',

    'new_user' => 'Ny Bruker',
    'new_product' => 'Nytt Produkt',
    'new_tax_rate' => 'Ny Skattesats',
    'invoiced_amount' => 'Invoiced Amount',
    'invoice_item_fields' => 'Invoice Item Fields',
    'custom_invoice_item_fields_help' => 'Add a field when creating an invoice item and display the label and value on the PDF.',
    'recurring_invoice_number' => 'Gjentakende nummer',
    'recurring_invoice_number_prefix_help' => 'Specify a prefix to be added to the invoice number for recurring invoices.',

    // Client Passwords
    'enable_portal_password' => 'Passord-beskytt fakturaer',
    'enable_portal_password_help' => 'Allows you to set a password for each contact. If a password is set, the contact will be required to enter a password before viewing invoices.',
    'send_portal_password' => 'Opprett Automatisk',
    'send_portal_password_help' => 'If no password is set, one will be generated and sent with the first invoice.',

    'expired' => 'Expired',
    'invalid_card_number' => 'The credit card number is not valid.',
    'invalid_expiry' => 'The expiration date is not valid.',
    'invalid_cvv' => 'The CVV is not valid.',
    'cost' => 'Kostnad',
    'create_invoice_for_sample' => 'Note: create your first invoice to see a preview here.',

    // User Permissions
    'owner' => 'Owner',
    'administrator' => 'Administrator',
    'administrator_help' => 'Allow user to manage users, change settings and modify all records',
    'user_create_all' => 'Create clients, invoices, etc.',
    'user_view_all' => 'View all clients, invoices, etc.',
    'user_edit_all' => 'Edit all clients, invoices, etc.',
    'gateway_help_20' => ':link to sign up for Sage Pay.',
    'gateway_help_21' => ':link to sign up for Sage Pay.',
    'partial_due' => 'Partial Due',
    'restore_vendor' => 'Restore Vendor',
    'restored_vendor' => 'Successfully restored vendor',
    'restored_expense' => 'Successfully restored expense',
    'permissions' => 'Permissions',
    'create_all_help' => 'Allow user to create and modify records',
    'view_all_help' => 'Allow user to view records they didn\'t create',
    'edit_all_help' => 'Allow user to modify records they didn\'t create',
    'view_payment' => 'View Payment',

    'january' => 'Januar',
    'february' => 'Februar',
    'march' => 'Mars',
    'april' => 'April',
    'may' => 'Mai',
    'june' => 'Juni',
    'july' => 'Juli',
    'august' => 'August',
    'september' => 'September',
    'october' => 'Oktober',
    'november' => 'November',
    'december' => 'Desember',

    // Documents
    'documents_header' => 'Dokumenter:',
    'email_documents_header' => 'Dokumenter:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Tilbudsdokumenter',
    'invoice_documents' => 'Fakturadokumenter',
    'expense_documents' => 'Utgiftsdokumenter',
    'invoice_embed_documents' => 'Embed Dokumenter',
    'invoice_embed_documents_help' => 'Include attached images in the invoice.',
    'document_email_attachment' => 'Legg ved dokumenter',
    'ubl_email_attachment' => 'Attach UBL',
    'download_documents' => 'Last ned dokumenter (:size)',
    'documents_from_expenses' => 'Fra Utgifter:',
    'dropzone_default_message' => 'Drop files or click to upload',
    'dropzone_default_message_disabled' => 'Opplasting deaktivert',
    'dropzone_fallback_message' => 'Your browser does not support drag\'n\'drop file uploads.',
    'dropzone_fallback_text' => 'Please use the fallback form below to upload your files like in the olden days.',
    'dropzone_file_too_big' => 'File is too big ({{filesize}}MiB). Max filesize: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'You can\'t upload files of this type.',
    'dropzone_response_error' => 'Server responded with {{statusCode}} code.',
    'dropzone_cancel_upload' => 'Cancel upload',
    'dropzone_cancel_upload_confirmation' => 'Are you sure you want to cancel this upload?',
    'dropzone_remove_file' => 'Remove file',
    'documents' => 'Dokumenter',
    'document_date' => 'Dokumentdato',
    'document_size' => 'Size',

    'enable_client_portal' => 'Kundeportal',
    'enable_client_portal_help' => 'Show/hide the dashboard page in the client portal.',
    'enable_client_portal_dashboard' => 'Dashboard',
    'enable_client_portal_dashboard_help' => 'Show/hide the dashboard page in the client portal.',

    // Plans
    'account_management' => 'Kontoadministrasjon',
    'plan_status' => 'Plan Status',

    'plan_upgrade' => 'Upgrade',
    'plan_change' => 'Change Plan',
    'pending_change_to' => 'Changes To',
    'plan_changes_to' => ':plan on :date',
    'plan_term_changes_to' => ':plan (:term) on :date',
    'cancel_plan_change' => 'Cancel Change',
    'plan' => 'Plan',
    'expires' => 'Expires',
    'renews' => 'Renews',
    'plan_expired' => ':plan Plan Expired',
    'trial_expired' => ':plan Plan Trial Ended',
    'never' => 'Never',
    'plan_free' => 'Free',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (White labeled)',
    'plan_free_self_hosted' => 'Self Hosted (Free)',
    'plan_trial' => 'Trial',
    'plan_term' => 'Term',
    'plan_term_monthly' => 'Månedlig',
    'plan_term_yearly' => 'Yearly',
    'plan_term_month' => 'Måned',
    'plan_term_year' => 'Year',
    'plan_price_monthly' => '$:price/måned',
    'plan_price_yearly' => '$:price/Year',
    'updated_plan' => 'Oppdaterte planinnstillinger',
    'plan_paid' => 'Term Started',
    'plan_started' => 'Plan Started',
    'plan_expires' => 'Plan Expires',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'One year enrollment in the Invoice Ninja Pro Plan.',
    'pro_plan_month_description' => 'One month enrollment in the Invoice Ninja Pro Plan.',
    'enterprise_plan_product' => 'Enterprise Plan',
    'enterprise_plan_year_description' => 'One year enrollment in the Invoice Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'One month enrollment in the Invoice Ninja Enterprise Plan.',
    'plan_credit_product' => 'Credit',
    'plan_credit_description' => 'Credit for unused time',
    'plan_pending_monthly' => 'Blitt endret til månedlig :date',
    'plan_refunded' => 'A refund has been issued.',

    'live_preview' => 'Live Preview',
    'page_size' => 'Page Size',
    'live_preview_disabled' => 'Live preview has been disabled to support selected font',
    'invoice_number_padding' => 'Padding',
    'preview' => 'Preview',
    'list_vendors' => 'List Vendors',
    'add_users_not_supported' => 'Upgrade to the Enterprise plan to add additional users to your account.',
    'enterprise_plan_features' => 'Enterprise-planen gir mulighet for flere brukere og filvedlegg, :link for å se hele listen med funksjoner.',
    'return_to_app' => 'Tilbake til App',


    // Payment updates
    'refund_payment' => 'Refunder betaling',
    'refund_max' => 'Maks:',
    'refund' => 'Refunder',
    'are_you_sure_refund' => 'Refunder valgte betalinger?',
    'status_pending' => 'Avventer',
    'status_completed' => 'Fullført',
    'status_failed' => 'Feilet',
    'status_partially_refunded' => 'Delvis Refundert',
    'status_partially_refunded_amount' => ':amount  Refundert',
    'status_refunded' => 'Refundert',
    'status_voided' => 'Kansellert',
    'refunded_payment' => 'Refundert betaling',
    'activity_39' => ':user cancelled a :payment_amount payment :payment',
    'activity_40' => ':user refunded :adjustment of a :payment_amount payment :payment',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'Ukjent',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Tillat bankoverføringer fra USA',
    'stripe_ach_help' => 'ACH-støtte må også være aktivert: :link.',
    'ach_disabled' => 'En annen gateway er allerede konfigurert for direkte belastning',

    'plaid' => 'Plaid',
    'client_id' => 'Kunde-ID',
    'secret' => 'Secret',
    'public_key' => 'Public Key',
    'plaid_optional' => '(optional)',
    'plaid_environment_help' => 'When a Stripe test key is given, Plaid\'s development environment (tartan) will be used.',
    'other_providers' => 'Andre tilbydere',
    'country_not_supported' => 'Landet er ikke støttet.',
    'invalid_routing_number' => 'Rutingsnummeret er ikke gyldig.',
    'invalid_account_number' => 'Kontonummeret er ikke gyldig.',
    'account_number_mismatch' => 'The account numbers do not match.',
    'missing_account_holder_type' => 'Please select an individual or company account.',
    'missing_account_holder_name' => 'Please enter the account holder\'s name.',
    'routing_number' => 'Routing Number',
    'confirm_account_number' => 'Bekreft Konto Nummer',
    'individual_account' => 'Individuell Konto',
    'company_account' => 'Firmakonto',
    'account_holder_name' => 'Kontoeiernavn',
    'add_account' => 'Legg til konto',
    'payment_methods' => 'Betalingsmåte',
    'complete_verification' => 'Ferdigstill Verifisering',
    'verification_amount1' => 'Beløp 1',
    'verification_amount2' => 'Beløp 2',
    'payment_method_verified' => 'Verifisering ble velykket',
    'verification_failed' => 'Verifisering feilet',
    'remove_payment_method' => 'Fjern Betalingsmåte',
    'confirm_remove_payment_method' => 'Er du sikker på at du vil fjerne denne betalingsmåten?',
    'remove' => 'Fjern',
    'payment_method_removed' => 'Fjernet betalingsmåte.',
    'bank_account_verification_help' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement. Please enter the amounts below.',
    'bank_account_verification_next_steps' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement.
        Once you have the amounts, come back to this payment methods page and click "Complete Verification" next to the account.',
    'unknown_bank' => 'Ukjent Bank',
    'ach_verification_delay_help' => 'You will be able to use the account after completing verification. Verification usually takes 1-2 business days.',
    'add_credit_card' => 'Legg til bankkort',
    'payment_method_added' => 'Betalingsmåte ble lagt til.',
    'use_for_auto_bill' => 'Use For Autobill',
    'used_for_auto_bill' => 'Autobill Payment Method',
    'payment_method_set_as_default' => 'Set Autobill payment method.',
    'activity_41' => ':payment_amount payment (:payment) failed',
    'webhook_url' => 'Webhook-URL',
    'stripe_webhook_help' => 'Du må :link.',
    'stripe_webhook_help_link_text' => 'add this URL as an endpoint at Stripe',
    'gocardless_webhook_help_link_text' => 'add this URL as an endpoint in GoCardless',
    'payment_method_error' => 'There was an error adding your payment methd. Please try again later.',
    'notification_invoice_payment_failed_subject' => 'Payment failed for Invoice :invoice',
    'notification_invoice_payment_failed' => 'A payment made by client :client towards Invoice :invoice failed. The payment has been marked as failed and :amount has been added to the client\'s balance.',
    'link_with_plaid' => 'Link Account Instantly with Plaid',
    'link_manually' => 'Link Manually',
    'secured_by_plaid' => 'Secured by Plaid',
    'plaid_linked_status' => 'Din bank konto i :bank',
    'add_payment_method' => 'Legg til betalingsmåte',
    'account_holder_type' => 'Account Holder Type',
    'ach_authorization' => 'I authorize :company to use my bank account for future payments and, if necessary, electronically credit my account to correct erroneous debits. I understand that I may cancel this authorization at any time by removing the payment method or by contacting :email.',
    'ach_authorization_required' => 'You must consent to ACH transactions.',
    'off' => 'Av',
    'opt_in' => 'Delta',
    'opt_out' => 'Ikke delta',
    'always' => 'Alltid',
    'opted_out' => 'Deltar ikke',
    'opted_in' => 'Deltar',
    'manage_auto_bill' => 'Manage Auto-bill',
    'enabled' => 'Aktivert',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Enable PayPal payments through BrainTree',
    'braintree_paypal_disabled_help' => 'The PayPal gateway is processing PayPal payments',
    'braintree_paypal_help' => 'Du må også :link.',
    'braintree_paypal_help_link_text' => 'link PayPal to your BrainTree account',
    'token_billing_braintree_paypal' => 'Lagre betalingsdetaljer',
    'add_paypal_account' => 'Legg til PayPal-konto',


    'no_payment_method_specified' => 'Ingen betalingsmåte er spesifisert',
    'chart_type' => 'Chart Type',
    'format' => 'Formater',
    'import_ofx' => 'Import OFX',
    'ofx_file' => 'OFX File',
    'ofx_parse_failed' => 'Failed to parse OFX file',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Sign up with WePay',
    'use_another_provider' => 'Bruk en annen tilbyder',
    'company_name' => 'Firmanavn',
    'wepay_company_name_help' => 'This will appear on client\'s credit card statements.',
    'wepay_description_help' => 'The purpose of this account.',
    'wepay_tos_agree' => 'I agree to the :link.',
    'wepay_tos_link_text' => 'WePay Terms of Service',
    'resend_confirmation_email' => 'Resend Confirmation Email',
    'manage_account' => 'Administrer konto',
    'action_required' => 'Handling kreves',
    'finish_setup' => 'Finish Setup',
    'created_wepay_confirmation_required' => 'Please check your email and confirm your email address with WePay.',
    'switch_to_wepay' => 'Switch to WePay',
    'switch' => 'Switch',
    'restore_account_gateway' => 'Restore Gateway',
    'restored_account_gateway' => 'Successfully restored gateway',
    'united_states' => 'Amerika',
    'canada' => 'Kanada',
    'accept_debit_cards' => 'Tillat Debetkort',
    'debit_cards' => 'Debetkort',

    'warn_start_date_changed' => 'Den neste fakturaen vil bli sendt på den nye startdatoen.',
    'warn_start_date_changed_not_sent' => 'The next invoice will be created on the new start date.',
    'original_start_date' => 'Opprinnelig startdato',
    'new_start_date' => 'Ny startdato',
    'security' => 'Sikkerhet',
    'see_whats_new' => 'See what\'s new in v:version',
    'wait_for_upload' => 'Please wait for the document upload to complete.',
    'upgrade_for_permissions' => 'Upgrade to our Enterprise plan to enable permissions.',
    'enable_second_tax_rate' => 'Aktiver for å spesifisere en <b>ekstra skattesats</b>',
    'payment_file' => 'Payment File',
    'expense_file' => 'Expense File',
    'product_file' => 'Product File',
    'import_products' => 'Importer Produkter',
    'products_will_create' => 'produkter vil bli opprettet',
    'product_key' => 'Produkt',
    'created_products' => 'Opprettet/Oppdaterte :count produkt(er)',
    'export_help' => 'Bruk JSON hvis du planlegger å importere dataene til Invoice Ninja. <br/>Filen inneholder kunder, produkter, fakturaer, tilbud og betalinger.',
    'selfhost_export_help' => 'Vi anbefaler bruk av mysqldump for å lage full sikkerhetskopi.',
    'JSON_file' => 'JSON-fil',

    'view_dashboard' => 'View Dashboard',
    'client_session_expired' => 'Session Expired',
    'client_session_expired_message' => 'Your session has expired. Please click the link in your email again.',

    'auto_bill_notification' => 'This invoice will automatically be billed to your :payment_method on file on :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'bankkonto',
    'auto_bill_payment_method_credit_card' => 'betalingskort',
    'auto_bill_payment_method_paypal' => 'PayPal-konto',
    'auto_bill_notification_placeholder' => 'This invoice will automatically be billed to your credit card on file on the due date.',
    'payment_settings' => 'Betalingsinnstillinger',

    'on_send_date' => 'På sendingsdato',
    'on_due_date' => 'Ved forfallsdato',
    'auto_bill_ach_date_help' => 'ACH will always auto bill on the due date.',
    'warn_change_auto_bill' => 'Due to NACHA rules, changes to this invoice may prevent ACH auto bill.',

    'bank_account' => 'Bankkonto',
    'payment_processed_through_wepay' => 'ACH payments will be processed using WePay.',
    'wepay_payment_tos_agree' => 'I agree to the WePay :terms and :privacy_policy.',
    'privacy_policy' => 'Personvernregler',
    'wepay_payment_tos_agree_required' => 'You must agree to the WePay Terms of Service and Privacy Policy.',
    'ach_email_prompt' => 'Fyll inn din epost adresse',
    'verification_pending' => 'Venter på godkjenning',

    'update_font_cache' => 'Please force refresh the page to update the font cache.',
    'more_options' => 'Flere valg',
    'credit_card' => 'Betalingskort',
    'bank_transfer' => 'Bankoverføring',
    'no_transaction_reference' => 'We did not recieve a payment transaction reference from the gateway.',
    'use_bank_on_file' => 'Bruk lagret bank informasjon',
    'auto_bill_email_message' => 'This invoice will automatically be billed to the payment method on file on the due date.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Lagt til :date',
    'failed_remove_payment_method' => 'Klarte ikke å fjerne betalingsmåte',
    'gateway_exists' => 'This gateway already exists',
    'manual_entry' => 'Legg til manuelt',
    'start_of_week' => 'Første dag i uken',

    // Frequencies
    'freq_inactive' => 'ikke aktiv',
    'freq_daily' => 'Daglig',
    'freq_weekly' => 'Ukentlig',
    'freq_biweekly' => 'Annehver uke',
    'freq_two_weeks' => 'To uker',
    'freq_four_weeks' => 'Fire uker',
    'freq_monthly' => 'Månedlig',
    'freq_three_months' => 'Tre måneder',
    'freq_four_months' => 'Fire måneder',
    'freq_six_months' => 'Seks måneder',
    'freq_annually' => 'Årlig',
    'freq_two_years' => 'To år',

    // Payment types
    'payment_type_Apply Credit' => 'Apply Credit',
    'payment_type_Bank Transfer' => 'Bankoverføring',
    'payment_type_Cash' => 'Kontanter',
    'payment_type_Debit' => 'Debet',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visakort',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Andre Betalingskort',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Sjekk',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Regnskap & Juridisk',
    'industry_Advertising' => 'Reklame',
    'industry_Aerospace' => 'Luftfart',
    'industry_Agriculture' => 'Jordbruk',
    'industry_Automotive' => 'Bil',
    'industry_Banking & Finance' => 'Bank & Finans',
    'industry_Biotechnology' => 'Bioteknologi',
    'industry_Broadcasting' => 'Kringkasting',
    'industry_Business Services' => 'Bedriftstjenester',
    'industry_Commodities & Chemicals' => 'Råvarer & kjemikalier',
    'industry_Communications' => 'Kommunikasjon',
    'industry_Computers & Hightech' => 'Datamaskiner & høyteknologi',
    'industry_Defense' => 'Forsvar',
    'industry_Energy' => 'Kraft',
    'industry_Entertainment' => 'Underholdning',
    'industry_Government' => 'Statlig',
    'industry_Healthcare & Life Sciences' => 'Helse- og livsvitenskap',
    'industry_Insurance' => 'Forsikring',
    'industry_Manufacturing' => 'Produksjon',
    'industry_Marketing' => 'Markedsføring',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Ideelle virksomheter og høyere utdanning',
    'industry_Pharmaceuticals' => 'Farmasi',
    'industry_Professional Services & Consulting' => 'Konsulenttjenester',
    'industry_Real Estate' => 'Eiendom',
    'industry_Restaurant & Catering' => 'Restaurant & Catering',
    'industry_Retail & Wholesale' => 'Detaljhandel & engros',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Reise & Luksus',
    'industry_Other' => 'Andre',
    'industry_Photography' => 'Foto',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarktis',
    'country_Algeria' => 'Algerie',
    'country_American Samoa' => 'Amerikansk Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Aserbajdsjan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgium',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia-Hercegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brasil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgaria',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Cameroon',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'Kina',
    'country_Taiwan, Province of China' => 'Taiwan, Province of China',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Kongo',
    'country_Congo, the Democratic Republic of the' => 'Congo, the Democratic Republic of the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croatia',
    'country_Cuba' => 'Kuba',
    'country_Cyprus' => 'Kypros',
    'country_Czech Republic' => 'Tsjekkia',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Danmark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominikanske Republikk',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Ethiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estland',
    'country_Faroe Islands' => 'Færøyene',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia and the South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland',
    'country_France' => 'Frankrike',
    'country_French Guiana' => 'Fransk Guyana',
    'country_French Polynesia' => 'Fransk Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Tyskland',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Hellas',
    'country_Greenland' => 'Grønland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican City State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Ungarn',
    'country_Iceland' => 'Island',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Iran, Den islamske republikk ',
    'country_Iraq' => 'Irak',
    'country_Ireland' => 'Irland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italia',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kirgisistan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Libanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Latvia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libya',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Litauen',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagaskar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Netherlands',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'New Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norge',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Polen',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Romania',
    'country_Russian Federation' => 'Russland',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi-Arabia',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Vietnam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'Sør-Afrika',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spania',
    'country_South Sudan' => 'Sør-Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Vest-Sahara',
    'country_Suriname' => 'Surinam',
    'country_Svalbard and Jan Mayen' => 'Svalbard og Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sverige',
    'country_Switzerland' => 'Sveits',
    'country_Syrian Arab Republic' => 'Den arabiske republikk Syria',
    'country_Tajikistan' => 'Tadsjikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad og Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Tyrkia',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraina',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia, the former Yugoslav Republic of',
    'country_Egypt' => 'Egypt',
    'country_United Kingdom' => 'Storbritannia',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'USA',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Jemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brazilian Portuguese',
    'lang_Croatian' => 'Kroatia',
    'lang_Czech' => 'Tsjekkisk',
    'lang_Danish' => 'Dansk',
    'lang_Dutch' => 'Nederlandsk',
    'lang_English' => 'Engelsk',
    'lang_French' => 'Fransk',
    'lang_French - Canada' => 'French - Canada',
    'lang_German' => 'Tysk',
    'lang_Italian' => 'Italiensk',
    'lang_Japanese' => 'Japansk',
    'lang_Lithuanian' => 'Lithuanian',
    'lang_Norwegian' => 'Norsk',
    'lang_Polish' => 'Polsk',
    'lang_Spanish' => 'Spansk',
    'lang_Spanish - Spain' => 'Spansk - Spania',
    'lang_Swedish' => 'Svensk',
    'lang_Albanian' => 'Albansk',
    'lang_Greek' => 'Gresk',
    'lang_English - United Kingdom' => 'Engelsk - Storbrittania',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => 'Slovensk',
    'lang_Finnish' => 'Finsk',
    'lang_Romanian' => 'Rumensk',
    'lang_Turkish - Turkey' => 'Tyrkisk - Tyrkia',
    'lang_Portuguese - Brazilian' => 'Portugisisk - brasiliansk',
    'lang_Portuguese - Portugal' => 'Portugisisk - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbian',
    'lang_Bulgarian' => 'Bulgarian',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Regnskap & Juridisk',
    'industry_Advertising' => 'Reklame',
    'industry_Aerospace' => 'Luftfart',
    'industry_Agriculture' => 'Jordbruk',
    'industry_Automotive' => 'Bil',
    'industry_Banking & Finance' => 'Bank & Finans',
    'industry_Biotechnology' => 'Bioteknologi',
    'industry_Broadcasting' => 'Kringkasting',
    'industry_Business Services' => 'Bedriftstjenester',
    'industry_Commodities & Chemicals' => 'Råvarer & kjemikalier',
    'industry_Communications' => 'Kommunikasjon',
    'industry_Computers & Hightech' => 'Datamaskiner & høyteknologi',
    'industry_Defense' => 'Forsvar',
    'industry_Energy' => 'Kraft',
    'industry_Entertainment' => 'Underholdning',
    'industry_Government' => 'Statlig',
    'industry_Healthcare & Life Sciences' => 'Helse- og livsvitenskap',
    'industry_Insurance' => 'Forsikring',
    'industry_Manufacturing' => 'Produksjon',
    'industry_Marketing' => 'Markedsføring',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Ideelle virksomheter og høyere utdanning',
    'industry_Pharmaceuticals' => 'Farmasi',
    'industry_Professional Services & Consulting' => 'Konsulenttjenester',
    'industry_Real Estate' => 'Eiendom',
    'industry_Retail & Wholesale' => 'Detaljhandel & engros',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Reise & Luksus',
    'industry_Other' => 'Andre',
    'industry_Photography' => 'Foto',

    'view_client_portal' => 'Vis kundeportal',
    'view_portal' => 'Vis Portal',
    'vendor_contacts' => 'Leverandørkontakter',
    'all' => 'Alle',
    'selected' => 'Valgt',
    'category' => 'Kategori',
    'categories' => 'Kategorier',
    'new_expense_category' => 'Ny Utgiftskategori',
    'edit_category' => 'Rediger Utgiftskategori',
    'archive_expense_category' => 'Arkiver Kategori',
    'expense_categories' => 'Utgiftskategorier',
    'list_expense_categories' => 'Liste Utgiftskategorier',
    'updated_expense_category' => 'Oppdaterte utgiftskategori',
    'created_expense_category' => 'Utgiftskategori ble opprettet',
    'archived_expense_category' => 'Utgiftskategori ble arkivert',
    'archived_expense_categories' => ':count utgiftskategorier ble arkivert',
    'restore_expense_category' => 'Gjenopprett utgiftskategori',
    'restored_expense_category' => 'Utgiftskategori ble gjenopprettet',
    'apply_taxes' => 'Legg til skatt',
    'min_to_max_users' => ':min til :max brukere',
    'max_users_reached' => 'Maksimalt antall brukere er nådd.',
    'buy_now_buttons' => 'Betal Nå-knapper',
    'landing_page' => 'Landingsside',
    'payment_type' => 'Betalingsmetode',
    'form' => 'Skjema',
    'link' => 'Lenke',
    'fields' => 'Felter',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Note: the client and invoice are created even if the transaction isn\'t completed.',
    'buy_now_buttons_disabled' => 'This feature requires that a product is created and a payment gateway is configured.',
    'enable_buy_now_buttons_help' => 'Aktiver støtte for Kjøp Nå-knapper',
    'changes_take_effect_immediately' => 'Merk: Endringer trer i kraft umiddelbart',
    'wepay_account_description' => 'Payment gateway for Invoice Ninja',
    'payment_error_code' => 'There was an error processing your payment [:code]. Please try again later.',
    'standard_fees_apply' => 'Fee: 2.9%/1.2% [Credit Card/Bank Transfer] + $0.30 per successful charge.',
    'limit_import_rows' => 'Data needs to be imported in batches of :count rows or less',
    'error_title' => 'Noe gikk galt',
    'error_contact_text' => 'If you\'d like help please email us at :mailaddress',
    'no_undo' => 'Warning: this can\'t be undone.',
    'no_contact_selected' => 'Vennligst velg en kontakt',
    'no_client_selected' => 'Vennligst velg en klient',

    'gateway_config_error' => 'It may help to set new passwords or generate new API keys.',
    'payment_type_on_file' => ':type on file',
    'invoice_for_client' => 'Invoice :invoice for :client',
    'intent_not_found' => 'Unnskyld, jeg er ikke sikker på hva du spør om.',
    'intent_not_supported' => 'Unnskyld, jeg kan ikke gjøre det.',
    'client_not_found' => 'Jeg kunne ikke finne klienten',
    'not_allowed' => 'Beklager, du har ikke tilgangsnivå som tillater dette',
    'bot_emailed_invoice' => 'Din faktura har blitt sendt.',
    'bot_emailed_notify_viewed' => 'I\'ll email you when it\'s viewed.',
    'bot_emailed_notify_paid' => 'I\'ll email you when it\'s paid.',
    'add_product_to_invoice' => 'Add 1 :product',
    'not_authorized' => 'You are not authorized',
    'bot_get_email' => 'Hi! (wave)<br/>Thanks for trying the Invoice Ninja Bot.<br/>You need to create a free account to use this bot.<br/>Send me your account email address to get started.',
    'bot_get_code' => 'Takk! Jeg har sendt deg en epost med din sikkerhetskode.',
    'bot_welcome' => 'Det var alt, din konto er godkjent.',
    'email_not_found' => 'Jeg kan ikke finne tilgjengelig konto for :email',
    'invalid_code' => 'Koden er ikke korrekt',
    'security_code_email_subject' => 'Sikkerhetskode for Invoice Ninja Bot',
    'security_code_email_line1' => 'Dette er din Invoice Ninja Bot\'s sikkerhetskode.',
    'security_code_email_line2' => 'Merk: Den går ut om 10 minutter.',
    'bot_help_message' => 'I currently support:<br/>• Create\update\email an invoice<br/>• List products<br/>For example:<br/><i>invoice bob for 2 tickets, set the due date to next thursday and the discount to 10 percent</i>',
    'list_products' => 'List opp produkter',

    'include_item_taxes_inline' => 'Inkluder <b>produktlinje-skatter i totalen</b>',
    'created_quotes' => 'Successfully created :count quotes(s)',
    'limited_gateways' => 'Note: we support one credit card gateway per company.',

    'warning' => 'Advarsel',
    'self-update' => 'Oppdater',
    'update_invoiceninja_title' => 'Oppdater Invoice Ninja',
    'update_invoiceninja_warning' => 'Before start upgrading Invoice Ninja create a backup of your database and files!',
    'update_invoiceninja_available' => 'A new version of Invoice Ninja is available.',
    'update_invoiceninja_unavailable' => 'No new version of Invoice Ninja available.',
    'update_invoiceninja_instructions' => 'Please install the new version <strong>:version</strong> by clicking the <em>Update now</em> button below. Afterwards you\'ll be redirected to the dashboard.',
    'update_invoiceninja_update_start' => 'Oppdater nå',
    'update_invoiceninja_download_start' => 'Last ned :version',
    'create_new' => 'Lag ny',

    'toggle_navigation' => 'Veksle til Navigasjon',
    'toggle_history' => 'Veksle til Historie',
    'unassigned' => 'Ikke tilordnet',
    'task' => 'Oppgave',
    'contact_name' => 'Kontakt navn',
    'city_state_postal' => 'By/Fylke/Postnummer',
    'custom_field' => 'egendefinert felt',
    'account_fields' => 'Firma felt',
    'facebook_and_twitter' => 'Facebook og Twitter',
    'facebook_and_twitter_help' => 'Follow our feeds to help support our project',
    'reseller_text' => 'Note: the white-label license is intended for personal use, please email us at :email if you\'d like to resell the app.',
    'unnamed_client' => 'Unnamed Client',

    'day' => 'Dag',
    'week' => 'Uke',
    'month' => 'Måned',
    'inactive_logout' => 'You have been logged out due to inactivity',
    'reports' => 'Rapporter',
    'total_profit' => 'Total Fortjeneste',
    'total_expenses' => 'Totale Utgifter',
    'quote_to' => 'Quote to',

    // Limits
    'limit' => 'Grense',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Maks: :max',
    'no_limit' => 'Ingen grenser',
    'set_limits' => 'Set :gateway_type Limits',
    'enable_min' => 'Aktiver min',
    'enable_max' => 'Aktiver maks',
    'min' => 'Min',
    'max' => 'Maks',
    'limits_not_met' => 'This invoice does not meet the limits for that payment type.',

    'date_range' => 'Datoperiode',
    'raw' => 'Rå',
    'raw_html' => 'Rå HTML',
    'update' => 'Oppdater',
    'invoice_fields_help' => 'Drag and drop fields to change their order and location',
    'new_category' => 'Ny Kategori',
    'restore_product' => 'Gjenopprett Produkt',
    'blank' => 'Tom',
    'invoice_save_error' => 'Det oppstod en feil under lagring av fakturaen',
    'enable_recurring' => 'Aktiver Gjentakende',
    'disable_recurring' => 'Deaktiver Gjentakende',
    'text' => 'Tekst',
    'expense_will_create' => 'utgift vil bli opprettet',
    'expenses_will_create' => 'utgifter vil bli opprettet',
    'created_expenses' => 'Opprettet :count utgift(er)',

    'translate_app' => 'Bidra til å forbedre våre oversettelser med :link',
    'expense_category' => 'Utgiftskategori',

    'go_ninja_pro' => 'Go Ninja Pro!',
    'go_enterprise' => 'Go Enterprise!',
    'upgrade_for_features' => 'Upgrade For More Features',
    'pay_annually_discount' => 'Pay annually for 10 months + 2 free!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Customize every aspect of your invoice!',
    'enterprise_upgrade_feature1' => 'Set permissions for multiple-users',
    'enterprise_upgrade_feature2' => 'Legg ved tredjeparts filer til fakturaer & utgifter',
    'much_more' => 'Mye Mer!',
    'all_pro_fetaures' => 'Plus all pro features!',

    'currency_symbol' => 'Symbol',
    'currency_code' => 'Kode',

    'buy_license' => 'Kjøp lisens',
    'apply_license' => 'aktiver lisens',
    'submit' => 'Send',
    'white_label_license_key' => 'lisens nøkkel',
    'invalid_white_label_license' => 'The white label license is not valid',
    'created_by' => 'Laget av :name',
    'modules' => 'Moduler',
    'financial_year_start' => 'Første måned i året',
    'authentication' => 'Autentisering',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Signatur',
    'show_accept_invoice_terms' => 'Invoice Terms Checkbox',
    'show_accept_invoice_terms_help' => 'Require client to confirm that they accept the invoice terms.',
    'show_accept_quote_terms' => 'Quote Terms Checkbox',
    'show_accept_quote_terms_help' => 'Require client to confirm that they accept the quote terms.',
    'require_invoice_signature' => 'Faktura-signatur',
    'require_invoice_signature_help' => 'Krever klients signatur.',
    'require_quote_signature' => 'Tilbuds-signatur',
    'require_quote_signature_help' => 'Krever klients signatur.',
    'i_agree' => 'Jeg godtar vilkårene',
    'sign_here' => 'Vennligst signer her:',
    'authorization' => 'Autorisasjon',
    'signed' => 'Signert',

    // BlueVine
    'bluevine_promo' => 'Get flexible business lines of credit and invoice factoring using BlueVine.',
    'bluevine_modal_label' => 'Sign up with BlueVine',
    'bluevine_modal_text' => '<h3>Fast funding for your business. No paperwork.</h3>
<ul><li>Flexible business lines of credit and invoice factoring.</li></ul>',
    'bluevine_create_account' => 'Opprett en konto',
    'quote_types' => 'Få et tilbud for',
    'invoice_factoring' => 'Invoice factoring',
    'line_of_credit' => 'Linje av kreditt',
    'fico_score' => 'Din FICO-poengsum',
    'business_inception' => 'Bedriftens stiftelsesdato',
    'average_bank_balance' => 'Average bank account balance',
    'annual_revenue' => 'Årlig omsetning',
    'desired_credit_limit_factoring' => 'Desired invoice factoring limit',
    'desired_credit_limit_loc' => 'Ønsket kreditt grense',
    'desired_credit_limit' => 'Ønsket kreditt grense',
    'bluevine_credit_line_type_required' => 'Du må velge minst en',
    'bluevine_field_required' => 'Dette feltet er obligatorisk',
    'bluevine_unexpected_error' => 'An unexpected error occurred.',
    'bluevine_no_conditional_offer' => 'More information is required before getting a quote. Click continue below.',
    'bluevine_invoice_factoring' => 'Invoice Factoring',
    'bluevine_conditional_offer' => 'Betinget Tilbud',
    'bluevine_credit_line_amount' => 'Kredittlinje',
    'bluevine_advance_rate' => 'Advance Rate',
    'bluevine_weekly_discount_rate' => 'Weekly Discount Rate',
    'bluevine_minimum_fee_rate' => 'Minimum Fee',
    'bluevine_line_of_credit' => 'Linje av Kreditt',
    'bluevine_interest_rate' => 'Rente',
    'bluevine_weekly_draw_rate' => 'Weekly Draw Rate',
    'bluevine_continue' => 'Continue to BlueVine',
    'bluevine_completed' => 'BlueVine signup completed',

    'vendor_name' => 'Leverandør',
    'entity_state' => 'Tilstand',
    'client_created_at' => 'Dato Opprettet',
    'postmark_error' => 'There was a problem sending the email through Postmark: :link',
    'project' => 'Prosjekt',
    'projects' => 'Prosjekter',
    'new_project' => 'Nytt Prosjekt',
    'edit_project' => 'Rediger Prosjekt',
    'archive_project' => 'Arkiver Prosjekt',
    'list_projects' => 'Liste Prosjekter',
    'updated_project' => 'Oppdaterte prosjekt',
    'created_project' => 'Opprettet prosjekt',
    'archived_project' => 'Arkiverte prosjekt',
    'archived_projects' => 'Arkiverte :count prosjekter',
    'restore_project' => 'Gjenopprett Prosjekt',
    'restored_project' => 'Gjenopprettet prosjekt',
    'delete_project' => 'Slett Prosjekt',
    'deleted_project' => 'Slettet prosjekt',
    'deleted_projects' => 'Slettet :count prosjekter',
    'delete_expense_category' => 'Slett kategori',
    'deleted_expense_category' => 'Slettet kategori',
    'delete_product' => 'Slett Produkt',
    'deleted_product' => 'Slettet produkt',
    'deleted_products' => 'Slettet :count produkter',
    'restored_product' => 'Gjenopprettet produkt',
    'update_credit' => 'Oppdater Kredit',
    'updated_credit' => 'Kredit oppdatert',
    'edit_credit' => 'Rediger Kredit',
    'realtime_preview' => 'Realtime Preview',
    'realtime_preview_help' => 'Realtime refresh PDF preview on the invoice page when editing invoice.<br/>Disable this to improve performance when editing invoices.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.',
    'force_pdfjs_help' => 'Replace the built-in PDF viewer in :chrome_link and :firefox_link.<br/>Enable this if your browser is automatically downloading the PDF.',
    'force_pdfjs' => 'Ikke tillat nedlasting',
    'redirect_url' => 'Omdirigerer URL',
    'redirect_url_help' => 'Optionally specify a URL to redirect to after a payment is entered.',
    'save_draft' => 'Lagre Kladd',
    'refunded_credit_payment' => 'Refunded credit payment',
    'keyboard_shortcuts' => 'Tastatursnarveier',
    'toggle_menu' => 'Toggle Menu',
    'new_...' => 'Ny ...',
    'list_...' => 'Liste ...',
    'created_at' => 'Dato Opprettet',
    'contact_us' => 'Kontakt Oss',
    'user_guide' => 'Brukerguide',
    'promo_message' => 'Upgrade before :expires and get :amount OFF your first year of our Pro or Enterprise packages.',
    'discount_message' => ':amount av utløper :expires',
    'mark_paid' => 'Merk som betalt',
    'marked_sent_invoice' => 'Successfully marked invoice sent',
    'marked_sent_invoices' => 'Successfully marked invoices sent',
    'invoice_name' => 'Faktura',
    'product_will_create' => 'produkt vil bli laget',
    'contact_us_response' => 'Thank you for your message! We\'ll try to respond as soon as possible.',
    'last_7_days' => 'Siste 7 dager',
    'last_30_days' => 'Siste 30 dager',
    'this_month' => 'Denne måneden',
    'last_month' => 'Siste måned',
    'current_quarter' => 'Current Quarter',
    'last_quarter' => 'Last Quarter',
    'last_year' => 'Siste år',
    'custom_range' => 'Tilpass Utvalg',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Krev',
    'license_expiring' => 'Merk: Din lisens will utløpe om :count dager, :link for å fornye den.',
    'security_confirmation' => 'Din e-postadresse ble bekreftet.',
    'white_label_expired' => 'Your white label license has expired, please consider renewing it to help support our project.',
    'renew_license' => 'Fornye lisens',
    'iphone_app_message' => 'Consider downloading our :link',
    'iphone_app' => 'iPhone-app',
    'android_app' => 'Android-app',
    'logged_in' => 'Innlogget',
    'switch_to_primary' => 'Switch to your primary company (:name) to manage your plan.',
    'inclusive' => 'Inklusiv',
    'exclusive' => 'Ekslusiv',
    'postal_city_state' => 'Postnr./Sted/Fylke',
    'phantomjs_help' => 'In certain cases the app uses :link_phantom to generate the PDF, install :link_docs to generate it locally.',
    'phantomjs_local' => 'Bruker lokal PhantomJS',
    'client_number' => 'Kundenummer',
    'client_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the client number.',
    'next_client_number' => 'Det neste kundenummeret er :number.',
    'generated_numbers' => 'Genererte Nummere',
    'notes_reminder1' => 'Første Påminnelse',
    'notes_reminder2' => 'Andre Påminnelse',
    'notes_reminder3' => 'Tredje Påminnelse',
    'notes_reminder4' => 'Reminder',
    'bcc_email' => 'BCC E-post',
    'tax_quote' => 'Tax Quote',
    'tax_invoice' => 'Tax Invoice',
    'emailed_invoices' => 'E-postfakturaer sendt',
    'emailed_quotes' => 'Tilbud sendt som e-post',
    'website_url' => 'Nettside-adresse',
    'domain' => 'Domene',
    'domain_help' => 'Used in the client portal and when sending emails.',
    'domain_help_website' => 'Used when sending emails.',
    'import_invoices' => 'Importer Fakturaer',
    'new_report' => 'Ny Rapport',
    'edit_report' => 'Rediger Rapport',
    'columns' => 'Kolonner',
    'filters' => 'Filtre',
    'sort_by' => 'Grupper Etter',
    'draft' => 'Kladd',
    'unpaid' => 'Ubetalt',
    'aging' => 'Aging',
    'age' => 'Alder',
    'days' => 'Dager',
    'age_group_0' => '0 - 30 Dager',
    'age_group_30' => '30 - 60 Dager',
    'age_group_60' => '60 - 90 Dager',
    'age_group_90' => '90 - 120 Dager',
    'age_group_120' => 'Mer enn 120 dager',
    'invoice_details' => 'Fakturadetaljer',
    'qty' => 'Antall',
    'profit_and_loss' => 'Fortjeneste og Tap',
    'revenue' => 'Omsetning',
    'profit' => 'Fortjeneste',
    'group_when_sorted' => 'Group Sort',
    'group_dates_by' => 'Grupper Datoer Etter',
    'year' => 'År',
    'view_statement' => 'Se Erklæring',
    'statement' => 'Erklæring',
    'statement_date' => 'Erklæringsdato',
    'mark_active' => 'Sett Aktiv',
    'send_automatically' => 'Send Automatisk',
    'initial_email' => 'Første E-post',
    'invoice_not_emailed' => 'This invoice hasn\'t been emailed.',
    'quote_not_emailed' => 'This quote hasn\'t been emailed.',
    'sent_by' => 'Sent av :user',
    'recipients' => 'Mottakere',
    'save_as_default' => 'Sett som standard',
    'start_of_week_help' => 'Used by <b>date</b> selectors',
    'financial_year_start_help' => 'Used by <b>date range</b> selectors',
    'reports_help' => 'Shift + Click to sort by multiple columns, Ctrl + Click to clear the grouping.',
    'this_year' => 'Dette Året',

    // Updated login screen
    'ninja_tagline' => 'Opprett. Send. Få Betalt.',
    'login_or_existing' => 'Or login with a connected account.',
    'sign_up_now' => 'Registrer Nå',
    'not_a_member_yet' => 'Ikke medlem enda?',
    'login_create_an_account' => 'Lag en konto!',

    // New Client Portal styling
    'invoice_from' => 'Fakturaer Fra:',
    'email_alias_message' => 'We require each company to have a unique email address.<br/>Consider using an alias. ie, email+label@example.com',
    'full_name' => 'Fullt Navn',
    'month_year' => 'MÅNED/ÅR',
    'valid_thru' => 'Gyldig\ngjennom',

    'product_fields' => 'Produktfelter',
    'custom_product_fields_help' => 'Add a field when creating a product or invoice and display the label and value on the PDF.',
    'freq_two_months' => 'To måneder',
    'freq_yearly' => 'Årlig',
    'profile' => 'Profil',
    'payment_type_help' => 'Sets the default <b>manual payment type</b>.',
    'industry_Construction' => 'Construction',
    'your_statement' => 'Din Erklæring',
    'statement_issued_to' => 'Erklæring sendt til',
    'statement_to' => 'Erklæring til',
    'customize_options' => 'Tilpass alternativer',
    'created_payment_term' => 'Successfully created payment term',
    'updated_payment_term' => 'Successfully updated payment term',
    'archived_payment_term' => 'Successfully archived payment term',
    'resend_invite' => 'Send invitasjon på nytt',
    'credit_created_by' => 'Credit created by payment :transaction_reference',
    'created_payment_and_credit' => 'Successfully created payment and credit',
    'created_payment_and_credit_emailed_client' => 'Successfully created payment and credit, and emailed client',
    'create_project' => 'Opprett prosjekt',
    'create_vendor' => 'Opprett leverandør',
    'create_expense_category' => 'Opprett kategori',
    'pro_plan_reports' => ':link to enable reports by joining the Pro Plan',
    'mark_ready' => 'Merk Klar',

    'limits' => 'Begrensninger',
    'fees' => 'Avgifter',
    'fee' => 'Avgift',
    'set_limits_fees' => 'Set :gateway_type Limits/Fees',
    'fees_tax_help' => 'Enable line item taxes to set the fee tax rates.',
    'fees_sample' => 'The fee for a :amount invoice would be :total.',
    'discount_sample' => 'The discount for a :amount invoice would be :total.',
    'no_fees' => 'Ingen Avgifter',
    'gateway_fees_disclaimer' => 'Warning: not all states/payment gateways allow adding fees, please review local laws/terms of service.',
    'percent' => 'Prosent',
    'location' => 'Lokasjon',
    'line_item' => 'Line Item',
    'surcharge' => 'Tilleggsgebyr',
    'location_first_surcharge' => 'Enabled - First surcharge',
    'location_second_surcharge' => 'Enabled - Second surcharge',
    'location_line_item' => 'Enabled - Line item',
    'online_payment_surcharge' => 'Online Payment Surcharge',
    'gateway_fees' => 'Gateway Fees',
    'fees_disabled' => 'Avgifter er skrudd av',
    'gateway_fees_help' => 'Automatically add an online payment surcharge/discount.',
    'gateway' => 'Gateway',
    'gateway_fee_change_warning' => 'If there are unpaid invoices with fees they need to be updated manually.',
    'fees_surcharge_help' => 'Customize surcharge :link.',
    'label_and_taxes' => 'label and taxes',
    'billable' => 'Fakturerbart',
    'logo_warning_too_large' => 'Bildet er for stort.',
    'logo_warning_fileinfo' => 'Warning: To support gifs the fileinfo PHP extension needs to be enabled.',
    'logo_warning_invalid' => 'There was a problem reading the image file, please try a different format.',

    'error_refresh_page' => 'An error occurred, please refresh the page and try again.',
    'data' => 'Data',
    'imported_settings' => 'Velykket importering av innstillinger',
    'reset_counter' => 'Nullstill Teller',
    'next_reset' => 'Neste Nullstilling',
    'reset_counter_help' => 'Automatically reset the invoice and quote counters.',
    'auto_bill_failed' => 'Auto-billing for invoice :invoice_number failed',
    'online_payment_discount' => 'Online Payment Discount',
    'created_new_company' => 'Successfully created new company',
    'fees_disabled_for_gateway' => 'Fees are disabled for this gateway.',
    'logout_and_delete' => 'Logg ut/Slett konto',
    'tax_rate_type_help' => 'Inclusive tax rates adjust the line item cost when selected.<br/>Only exclusive tax rates can be used as a default.',
    'invoice_footer_help' => 'Use $pageNumber and $pageCount to display the page information.',
    'credit_note' => 'Kreditnota',
    'credit_issued_to' => 'Credit issued to',
    'credit_to' => 'Credit to',
    'your_credit' => 'Din Kredit',
    'credit_number' => 'Kreditnummer',
    'create_credit_note' => 'Opprett Kreditnota',
    'menu' => 'Meny',
    'error_incorrect_gateway_ids' => 'Error: The gateways table has incorrect ids.',
    'purge_data' => 'Fjern data',
    'delete_data' => 'Slett data',
    'purge_data_help' => 'Permanently delete all data but keep the account and settings.',
    'cancel_account_help' => 'Permanently delete the account along with all data and setting.',
    'purge_successful' => 'Successfully purged company data',
    'forbidden' => 'Ikke tillatt',
    'purge_data_message' => 'Advarsel: Dette sletter alle dine data permanent, og kan ikke gjennopprettes.',
    'contact_phone' => 'Kontakt Telefon',
    'contact_email' => 'Kontakt Epost',
    'reply_to_email' => 'Svar til Epost',
    'reply_to_email_help' => 'Specify the reply-to address for client emails.',
    'bcc_email_help' => 'Privately include this address with client emails.',
    'import_complete' => 'Your import has successfully completed.',
    'confirm_account_to_import' => 'Please confirm your account to import data.',
    'import_started' => 'Your import has started, we\'ll send you an email once it completes.',
    'listening' => 'Listening...',
    'microphone_help' => 'Say "new invoice for [client]" or "show me [client]\'s archived payments"',
    'voice_commands' => 'Stemme aktiverte kommandoer',
    'sample_commands' => 'Eksempel kommandoer',
    'voice_commands_feedback' => 'We\'re actively working to improve this feature, if there\'s a command you\'d like us to support please email us at :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => 'Successfully archived :count products',
    'recommend_on' => 'We recommend <b>enabling</b> this setting.',
    'recommend_off' => 'We recommend <b>disabling</b> this setting.',
    'notes_auto_billed' => 'Auto-billed',
    'surcharge_label' => 'Surcharge Label',
    'contact_fields' => 'Kontakt Felt',
    'custom_contact_fields_help' => 'Add a field when creating a contact and optionally display the label and value on the PDF.',
    'datatable_info' => 'Viser :start til :end av :total oppføringer',
    'credit_total' => 'Total kreditt',
    'mark_billable' => 'Mark billable',
    'billed' => 'Fakturert',
    'company_variables' => 'Firma variabler',
    'client_variables' => 'Klient variabler',
    'invoice_variables' => 'Faktura variabler',
    'navigation_variables' => 'Navigasjons variabler',
    'custom_variables' => 'Egendefinerte variabler',
    'invalid_file' => 'Ikke gyldig fil type',
    'add_documents_to_invoice' => 'Legg ved dokumenter til faktura',
    'mark_expense_paid' => 'Merk betalt',
    'white_label_license_error' => 'Failed to validate the license, check storage/logs/laravel-error.log for more details.',
    'plan_price' => 'Plan Price',
    'wrong_confirmation' => 'Incorrect confirmation code',
    'oauth_taken' => 'Denne kontoen er allerede registrert',
    'emailed_payment' => 'Successfully emailed payment',
    'email_payment' => 'E-postbetaling',
    'invoiceplane_import' => 'Use :link to migrate your data from InvoicePlane.',
    'duplicate_expense_warning' => 'Warning: This :link may be a duplicate',
    'expense_link' => 'utgift',
    'resume_task' => 'Fortsett Oppgave',
    'resumed_task' => 'Successfully resumed task',
    'quote_design' => 'Quote Design',
    'default_design' => 'Standard Design',
    'custom_design1' => 'Egendefinert Design 1',
    'custom_design2' => 'Egendefinert Design 2',
    'custom_design3' => 'Egendefinert Design 3',
    'empty' => 'Tom',
    'load_design' => 'Load Design',
    'accepted_card_logos' => 'Accepted Card Logos',
    'phantomjs_local_and_cloud' => 'Using local PhantomJS, falling back to phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Nøkkel',
    'analytics_key_help' => 'Spor betaling med :link',
    'start_date_required' => 'The start date is required',
    'application_settings' => 'Applikasjons Innstillinger',
    'database_connection' => 'Databasetilkobling',
    'driver' => 'Driver',
    'host' => 'Tjener',
    'database' => 'Database',
    'test_connection' => 'Test tilkobling',
    'from_name' => 'Fra Navn',
    'from_address' => 'Fra Addresse',
    'port' => 'Port',
    'encryption' => 'Kryptering',
    'mailgun_domain' => 'Mailgun Domene',
    'mailgun_private_key' => 'Mailgun Privat Nøkkel',
    'send_test_email' => 'Send test-e-post',
    'select_label' => 'Select Label',
    'label' => 'Label',
    'service' => 'Service',
    'update_payment_details' => 'Oppdater betalingsinformasjon',
    'updated_payment_details' => 'Vellykket oppdatering av betalingsinformasjon',
    'update_credit_card' => 'Oppdater kredittkort',
    'recurring_expenses' => 'Gjentakende Utgifter',
    'recurring_expense' => 'Gjentakende Utgift',
    'new_recurring_expense' => 'Opprett Gjentakende Utgift',
    'edit_recurring_expense' => 'Rediger Gjentakende Utgift',
    'archive_recurring_expense' => 'Arkiver Gjentakende Utgift',
    'list_recurring_expense' => 'Liste Gjentakende Utgifter',
    'updated_recurring_expense' => 'Successfully updated recurring expense',
    'created_recurring_expense' => 'Successfully created recurring expense',
    'archived_recurring_expense' => 'Successfully archived recurring expense',
    'restore_recurring_expense' => 'Restore Recurring Expense',
    'restored_recurring_expense' => 'Successfully restored recurring expense',
    'delete_recurring_expense' => 'Delete Recurring Expense',
    'deleted_recurring_expense' => 'Successfully deleted project',
    'view_recurring_expense' => 'Vis Gjentakende Utgift',
    'taxes_and_fees' => 'Skatt og avgifter',
    'import_failed' => 'Import Failed',
    'recurring_prefix' => 'Recurring Prefix',
    'options' => 'Valg',
    'credit_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the credit number for negative invoices.',
    'next_credit_number' => 'The next credit number is :number.',
    'padding_help' => 'The number of zero\'s to pad the number.',
    'import_warning_invalid_date' => 'Warning: The date format appears to be invalid.',
    'product_notes' => 'Produktnotater',
    'app_version' => 'Applikasjons Versjon',
    'ofx_version' => 'OFX Versjon',
    'gateway_help_23' => ':link to get your Stripe API keys.',
    'error_app_key_set_to_default' => 'Error: APP_KEY is set to a default value, to update it backup your database and then run <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Charge Late Fee',
    'late_fee_amount' => 'Late Fee Amount',
    'late_fee_percent' => 'Late Fee Percent',
    'late_fee_added' => 'Late fee added on :date',
    'download_invoice' => 'Last ned faktura',
    'download_quote' => 'Last ned tilbud',
    'invoices_are_attached' => 'Your invoice PDFs are attached.',
    'downloaded_invoice' => 'An email will be sent with the invoice PDF',
    'downloaded_quote' => 'An email will be sent with the quote PDF',
    'downloaded_invoices' => 'An email will be sent with the invoice PDFs',
    'downloaded_quotes' => 'An email will be sent with the quote PDFs',
    'clone_expense' => 'Kopier Utgift',
    'default_documents' => 'Standard-dokumenter',
    'send_email_to_client' => 'Send epost til klient',
    'refund_subject' => 'Tilbakebetaling utført',
    'refund_body' => 'You have been processed a refund of :amount for invoice :invoice_number.',

    'currency_us_dollar' => 'Amerikanske Dollar',
    'currency_british_pound' => 'Britiske Pund',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danske Kroner',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Svenske Kronor',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Kanadiske Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australske Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'We hope you\'re enjoying using the app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'skriv tilbakemelding',

    'use_english_version' => 'Make sure to use the English version of the files.<br/>We use the column headers to match the fields.',
    'tax1' => 'First Tax',
    'tax2' => 'Second Tax',
    'fee_help' => 'Gateway fees are the costs charged for access to the financial networks that handle the processing of online payments.',
    'format_export' => 'Eksporterings format',
    'custom1' => 'First Custom',
    'custom2' => 'Second Custom',
    'contact_first_name' => 'Kontakts fornavn',
    'contact_last_name' => 'Etternavn',
    'contact_custom1' => 'Contact First Custom',
    'contact_custom2' => 'Contact Second Custom',
    'currency' => 'Currency',
    'ofx_help' => 'To troubleshoot check for comments on :ofxhome_link and test with :ofxget_link.',
    'comments' => 'kommentarer',

    'item_product' => 'Item Product',
    'item_notes' => 'Oppføringsnotater',
    'item_cost' => 'Item Cost',
    'item_quantity' => 'Antall',
    'item_tax_rate' => 'Skatteprosent',
    'item_tax_name' => 'Item Tax Name',
    'item_tax1' => 'Item Tax1',
    'item_tax2' => 'Item Tax2',

    'delete_company' => 'Slett Firma',
    'delete_company_help' => 'Permanent sletting av firma data og innstillinger',
    'delete_company_message' => 'Advarsel: Dette vil permanent slette ditt firma, dette kan ikke gjennopprettes.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'The coupon has been applied, your account has been upgraded to pro for one year.',

    'contact_us_help' => 'If you\'re reporting an error please include any relevant logs from storage/logs/laravel-error.log',
    'include_errors' => 'Inkluder feilmeldinger',
    'include_errors_help' => 'Include :link from storage/logs/laravel-error.log',
    'recent_errors' => 'siste feilmeldinger',
    'customer' => 'Kunde',
    'customers' => 'Kunder',
    'created_customer' => 'Successfully created customer',
    'created_customers' => 'Successfully created :count customers',

    'purge_details' => 'The data in your company (:account) has been successfully purged.',
    'deleted_company' => 'Successfully deleted company',
    'deleted_account' => 'Successfully canceled account',
    'deleted_company_details' => 'Your company (:account) has been successfully deleted.',
    'deleted_account_details' => 'Your account (:account) has been successfully deleted.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Accept Alipay',
    'enable_sofort' => 'Tillat bankoverføringer fra EU',
    'stripe_alipay_help' => 'These gateways also need to be activated in :link.',
    'calendar' => 'Kalender',
    'pro_plan_calendar' => ':link for å aktivere kalenderen ved å ta i bruk Pro-plan',

    'what_are_you_working_on' => 'Hva jobber du med?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Refresh',
    'filter_sort' => 'Filter/Sort',
    'no_description' => 'Ingen beskrivelse',
    'time_tracker_login' => 'Time Tracker Login',
    'save_or_discard' => 'Save or discard your changes',
    'discard_changes' => 'Discard Changes',
    'tasks_not_enabled' => 'Tasks are not enabled.',
    'started_task' => 'Successfully started task',
    'create_client' => 'Create Client',

    'download_desktop_app' => 'Download the desktop app',
    'download_iphone_app' => 'Download the iPhone app',
    'download_android_app' => 'Download the Android app',
    'time_tracker_mobile_help' => 'Double tap a task to select it',
    'stopped' => 'Stoppede',
    'ascending' => 'Stigende',
    'descending' => 'Synkende',
    'sort_field' => 'Grupper Etter',
    'sort_direction' => 'Direction',
    'discard' => 'Discard',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Clear',
    'warn_payment_gateway' => 'Note: accepting online payments requires a payment gateway, :link to add one.',
    'task_rate' => 'Oppgavesats',
    'task_rate_help' => 'Setter standardrate for fakturerte oppgaver.',
    'past_due' => 'Forfalt',
    'document' => 'Dokument',
    'invoice_or_expense' => 'Faktura/Utgift',
    'invoice_pdfs' => 'Invoice PDFs',
    'enable_sepa' => 'Accept SEPA',
    'enable_bitcoin' => 'Accept Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'By providing your IBAN and confirming this payment, you are authorizing :company and Stripe, our payment service provider, to send instructions to your bank to debit your account and your bank to debit your account in accordance with those instructions. You are entitled to a refund from your bank under the terms and conditions of your agreement with your bank. A refund must be claimed within 8 weeks starting from the date on which your account was debited.',
    'recover_license' => 'Fjern Lisens',
    'purchase' => 'Kjøp',
    'recover' => 'Recover',
    'apply' => 'Bruk',
    'recover_white_label_header' => 'Recover White Label License',
    'apply_white_label_header' => 'Apply White Label License',
    'videos' => 'Videoer',
    'video' => 'Video',
    'return_to_invoice' => 'Return to Invoice',
    'gateway_help_13' => 'To use ITN leave the PDT Key field blank.',
    'partial_due_date' => 'Partial Due Date',
    'task_fields' => 'Task Fields',
    'product_fields_help' => 'Drag and drop fields to change their order',
    'custom_value1' => 'Custom Value',
    'custom_value2' => 'Custom Value',
    'enable_two_factor' => 'To-faktor-autentisering',
    'enable_two_factor_help' => 'Bruk telefonen til å bekrefte identiteten din når du logger inn',
    'two_factor_setup' => 'Two-Factor Setup',
    'two_factor_setup_help' => 'Scan the bar code with a :link compatible app.',
    'one_time_password' => 'Engangs Passord',
    'set_phone_for_two_factor' => 'Set your mobile phone number as a backup to enable.',
    'enabled_two_factor' => 'Aktiverte To-faktor-autentisering',
    'add_product' => 'Legg til produkt',
    'email_will_be_sent_on' => 'Note: the email will be sent on :date.',
    'invoice_product' => 'Fakturer Produkt',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Error: local storage is not available.',
    'your_password_reset_link' => 'Your Password Reset Link',
    'subdomain_taken' => 'Dette underdomenet er allerede i bruk',
    'client_login' => 'Kundeinnlogging',
    'converted_amount' => 'Converted Amount',
    'default' => 'Default',
    'shipping_address' => 'Leveringsadresse',
    'bllling_address' => 'Fakturerings Adresse',
    'billing_address1' => 'Fakturaadresse',
    'billing_address2' => 'Billing Apt/Suite',
    'billing_city' => 'Fakturering By',
    'billing_state' => 'Billing State/Province',
    'billing_postal_code' => 'Fakturering Postnummer',
    'billing_country' => 'Fakturering Land',
    'shipping_address1' => 'Leverings adresse',
    'shipping_address2' => 'Shipping Apt/Suite',
    'shipping_city' => 'Shipping City',
    'shipping_state' => 'Shipping State/Province',
    'shipping_postal_code' => 'Leverings adresse postnummer',
    'shipping_country' => 'Shipping Country',
    'classify' => 'Klassifiser',
    'show_shipping_address_help' => 'Require client to provide their shipping address',
    'ship_to_billing_address' => 'Ship to billing address',
    'delivery_note' => 'Delivery Note',
    'show_tasks_in_portal' => 'Vis oppgaver i kundeportalen',
    'cancel_schedule' => 'Kansellerer Planlegging',
    'scheduled_report' => 'Planlagt Rapport',
    'scheduled_report_help' => 'Email the :report report as :format to :email',
    'created_scheduled_report' => 'Successfully scheduled report',
    'deleted_scheduled_report' => 'Successfully canceled scheduled report',
    'scheduled_report_attached' => 'Your scheduled :type report is attached.',
    'scheduled_report_error' => 'Failed to create schedule report',
    'invalid_one_time_password' => 'Ugyldig engangs passord',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accept Apple Pay and Pay with Google',
    'requires_subdomain' => 'This payment type requires that a :link.',
    'subdomain_is_set' => 'subdomain is set',
    'verification_file' => 'Verification File',
    'verification_file_missing' => 'The verification file is needed to accept payments.',
    'apple_pay_domain' => 'Use <code>:domain</code> as the domain in :link.',
    'apple_pay_not_supported' => 'Sorry, Apple/Google Pay isn\'t supported by your browser',
    'optional_payment_methods' => 'Alternative betalingsmetoder',
    'add_subscription' => 'Legg til abonnement',
    'target_url' => 'Target',
    'target_url_help' => 'When the selected event occurs the app will post the entity to the target URL.',
    'event' => 'Event',
    'subscription_event_1' => 'Klient opprettet',
    'subscription_event_2' => 'Faktura opprettet',
    'subscription_event_3' => 'Tilbud opprettet',
    'subscription_event_4' => 'Created Payment',
    'subscription_event_5' => 'Opprettet leverandør',
    'subscription_event_6' => 'Updated Quote',
    'subscription_event_7' => 'Deleted Quote',
    'subscription_event_8' => 'Updated Invoice',
    'subscription_event_9' => 'Deleted Invoice',
    'subscription_event_10' => 'Updated Client',
    'subscription_event_11' => 'Deleted Client',
    'subscription_event_12' => 'Deleted Payment',
    'subscription_event_13' => 'Oppdaterte leverandør',
    'subscription_event_14' => 'Slettet leverandør',
    'subscription_event_15' => 'Opprettet utgift',
    'subscription_event_16' => 'Oppdaterte utgift',
    'subscription_event_17' => 'Slettet utgift',
    'subscription_event_18' => 'Created Task',
    'subscription_event_19' => 'Updated Task',
    'subscription_event_20' => 'Deleted Task',
    'subscription_event_21' => 'Tilbud godkjent',
    'subscriptions' => 'Abonnementer',
    'updated_subscription' => 'Oppdaterte abonnement',
    'created_subscription' => 'Abonnement opprettet',
    'edit_subscription' => 'Rediger Abonnement',
    'archive_subscription' => 'Arkiver Abonnement',
    'archived_subscription' => 'Abonnement arkivert',
    'project_error_multiple_clients' => 'The projects can\'t belong to different clients',
    'invoice_project' => 'Invoice Project',
    'module_recurring_invoice' => 'Recurring Invoices',
    'module_credit' => 'Credits',
    'module_quote' => 'Quotes & Proposals',
    'module_task' => 'Oppgaver & Prosjekter',
    'module_expense' => 'Utgifter & Leverandører',
    'module_ticket' => 'Tickets',
    'reminders' => 'Påminnelser',
    'send_client_reminders' => 'Send email reminders',
    'can_view_tasks' => 'Oppgaver er synlige i portalen',
    'is_not_sent_reminders' => 'Reminders are not sent',
    'promotion_footer' => 'Your promotion will expire soon, :link to upgrade now.',
    'unable_to_delete_primary' => 'Note: to delete this company first delete all linked companies.',
    'please_register' => 'Please register your account',
    'processing_request' => 'Processing request',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Edit Times',
    'inclusive_taxes_help' => 'Inkluder <b>skatter i kostnaden</b>',
    'inclusive_taxes_notice' => 'This setting can not be changed once an invoice has been created.',
    'inclusive_taxes_warning' => 'Warning: existing invoices will need to be resaved',
    'copy_shipping' => 'Copy Shipping',
    'copy_billing' => 'Copy Billing',
    'quote_has_expired' => 'The quote has expired, please contact the merchant.',
    'empty_table_footer' => 'Viser 0 til 0 av 0 oppføringer',
    'do_not_trust' => 'Do not remember this device',
    'trust_for_30_days' => 'Klarer for 30 dager',
    'trust_forever' => 'Trust forever',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready to do',
    'in_progress' => 'In progress',
    'add_status' => 'Add status',
    'archive_status' => 'Archive Status',
    'new_status' => 'New Status',
    'convert_products' => 'Convert Products',
    'convert_products_help' => 'Automatically convert product prices to the client\'s currency',
    'improve_client_portal_link' => 'Set a subdomain to shorten the client portal link.',
    'budgeted_hours' => 'Budgeted Hours',
    'progress' => 'Progress',
    'view_project' => 'Vis Prosjekt',
    'summary' => 'Summary',
    'endless_reminder' => 'Endless Reminder',
    'signature_on_invoice_help' => 'Add the following code to show your client\'s signature on the PDF.',
    'signature_on_pdf' => 'Show on PDF',
    'signature_on_pdf_help' => 'Show the client signature on the invoice/quote PDF.',
    'expired_white_label' => 'The white label license has expired',
    'return_to_login' => 'Return to Login',
    'convert_products_tip' => 'Note: add a :link named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'The amount is greater than the invoice balance, a credit will be created with the remaining amount.',
    'custom_fields_tip' => 'Use <code>Label|Option1,Option2</code> to show a select box.',
    'client_information' => 'Client Information',
    'updated_client_details' => 'Successfully updated client details',
    'auto' => 'Auto',
    'tax_amount' => 'Tax Amount',
    'tax_paid' => 'Tax Paid',
    'none' => 'None',
    'proposal_message_button' => 'To view your proposal for :amount, click the button below.',
    'proposal' => 'Forslag',
    'proposals' => 'Forslag',
    'list_proposals' => 'List Forslagene',
    'new_proposal' => 'Nytt Forslag',
    'edit_proposal' => 'Rediger Forslaget',
    'archive_proposal' => 'Arkiver Forslaget',
    'delete_proposal' => 'Slett Forslaget',
    'created_proposal' => 'Successfully created proposal',
    'updated_proposal' => 'Successfully updated proposal',
    'archived_proposal' => 'Successfully archived proposal',
    'deleted_proposal' => 'Successfully archived proposal',
    'archived_proposals' => 'Successfully archived :count proposals',
    'deleted_proposals' => 'Successfully archived :count proposals',
    'restored_proposal' => 'Successfully restored proposal',
    'restore_proposal' => 'Restore Proposal',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Mal',
    'templates' => 'Templates',
    'proposal_template' => 'Template',
    'proposal_templates' => 'Templates',
    'new_proposal_template' => 'New Template',
    'edit_proposal_template' => 'Edit Template',
    'archive_proposal_template' => 'Archive Template',
    'delete_proposal_template' => 'Delete Template',
    'created_proposal_template' => 'Successfully created template',
    'updated_proposal_template' => 'Successfully updated template',
    'archived_proposal_template' => 'Successfully archived template',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Successfully restored template',
    'restore_proposal_template' => 'Restore Template',
    'proposal_category' => 'Category',
    'proposal_categories' => 'Categories',
    'new_proposal_category' => 'New Category',
    'edit_proposal_category' => 'Edit Category',
    'archive_proposal_category' => 'Archive Category',
    'delete_proposal_category' => 'Delete Category',
    'created_proposal_category' => 'Successfully created category',
    'updated_proposal_category' => 'Successfully updated category',
    'archived_proposal_category' => 'Successfully archived category',
    'deleted_proposal_category' => 'Successfully archived category',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Restore Category',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'The requested proposal is not available',
    'create_proposal_category' => 'Create category',
    'clone_proposal_template' => 'Clone Template',
    'proposal_email' => 'Proposal Email',
    'proposal_subject' => 'New proposal :number from :account',
    'proposal_message' => 'To view your proposal for :amount, click the link below.',
    'emailed_proposal' => 'Successfully emailed proposal',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Add Image',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Delete Image',
    'delete_image_help' => 'Warning: deleting the image will remove it from all proposals.',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'Epost adresse er endret',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Loading',
    'no_messages_found' => 'No messages found',
    'processing' => 'Processing',
    'reactivate' => 'Reactivate',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Group',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve received a new payment!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Allow approve expired quote',
    'allow_approve_expired_quote_help' => 'Allow clients to approve expired quotes.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Quote Workflow',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Clone Product',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send line item details to the payment gateway.',
    'view_proposal' => 'View Proposal',
    'view_in_portal' => 'View in Portal',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'vendor will be created',
    'vendors_will_create' => 'vendors will be created',
    'created_vendors' => 'Successfully created :count vendor(s)',
    'import_vendors' => 'Import Vendors',
    'company' => 'Company',
    'client_field' => 'Client Field',
    'contact_field' => 'Contact Field',
    'product_field' => 'Product Field',
    'task_field' => 'Task Field',
    'project_field' => 'Project Field',
    'expense_field' => 'Expense Field',
    'vendor_field' => 'Vendor Field',
    'company_field' => 'Company Field',
    'invoice_field' => 'Invoice Field',
    'invoice_surcharge' => 'Invoice Surcharge',
    'custom_task_fields_help' => 'Add a field when creating a task.',
    'custom_project_fields_help' => 'Add a field when creating a project.',
    'custom_expense_fields_help' => 'Add a field when creating an expense.',
    'custom_vendor_fields_help' => 'Add a field when creating a vendor.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Unapproved Quote',
    'unapproved_proposal' => 'Unapproved Proposal',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Password Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Mark',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Background Image',
    'background_image_help' => 'Use the :link to manage your images, we recommend using a small file.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Show Payments',
    'show_aging' => 'Show Aging',
    'reference' => 'Reference',
    'amount_paid' => 'Amount Paid',
    'send_notifications_for' => 'Send Notifications For',
    'all_invoices' => 'All Invoices',
    'my_invoices' => 'My Invoices',
    'payment_reference' => 'Payment Reference',
    'maximum' => 'Maximum',
    'sort' => 'Sort',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Please enter your email',
    'please_enter_your_password' => 'Please enter your password',
    'please_enter_your_url' => 'Please enter your URL',
    'please_enter_a_product_key' => 'Please enter a product key',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Overview',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Error',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Updated',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Please enter a quote number',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Restart the app to apply the change',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank Contact',
    'no_records_found' => 'No records found',
    'industry' => 'Industry',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Show tasks',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Send',
    'auto_billing' => 'Auto billing',
    'button' => 'Button',
    'more' => 'More',
    'edit_recurring_invoice' => 'Edit Recurring Invoice',
    'edit_recurring_quote' => 'Edit Recurring Quote',
    'quote_status' => 'Quote Status',
    'please_select_an_invoice' => 'Please select an invoice',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Payment Status',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'New Ticket',
    'edit_ticket' => 'Edit Ticket',
    'view_ticket' => 'View Ticket',
    'archive_ticket' => 'Archive Ticket',
    'restore_ticket' => 'Restore Ticket',
    'delete_ticket' => 'Delete Ticket',
    'archived_ticket' => 'Successfully archived ticket',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Successfully deleted ticket',
    'open' => 'Open',
    'new' => 'New',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Priority',
    'last_updated' => 'Last Updated',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'No due date set',
    'assigned_to' => 'Assigned to',
    'reply' => 'Reply',
    'awaiting_reply' => 'Awaiting reply',
    'ticket_close' => 'Close Ticket',
    'ticket_reopen' => 'Reopen Ticket',
    'ticket_open' => 'Open Ticket',
    'ticket_split' => 'Split Ticket',
    'ticket_merge' => 'Merge Ticket',
    'ticket_update' => 'Update Ticket',
    'ticket_settings' => 'Ticket Settings',
    'updated_ticket' => 'Ticket Updated',
    'mark_spam' => 'Mark as Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Navn er allerede tatt',
    'local_part_available' => 'Navn tilgjengelig',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'Client uploads',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Maximum file size',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Ticket number must be greater than the current ticket number',
    'new_ticket_template_id' => 'New ticket',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Updated ticket',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Closed ticket',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Default priority',
    'alert_new_comment_id' => 'New comment',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Ticket not found',
    'add_template' => 'Add Template',
    'ticket_template' => 'Ticket Template',
    'ticket_templates' => 'Ticket Templates',
    'updated_ticket_template' => 'Updated Ticket Template',
    'created_ticket_template' => 'Created Ticket Template',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Show / Hide all',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'To upload a background image :link to enable the proposals module.',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Select Ticket',
    'new_internal_ticket' => 'New internal ticket',
    'internal_ticket' => 'Internal ticket',
    'create_ticket' => 'Create ticket',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compare',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Today',
    'current' => 'Current',
    'previous' => 'Previous',
    'current_period' => 'Current Period',
    'comparison_period' => 'Comparison Period',
    'previous_period' => 'Previous Period',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Compare to',
    'last_week' => 'Last Week',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Clone to Quote',
    'convert' => 'Convert',
    'last7_days' => 'Last 7 Days',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Show product details',
    'show_product_notes_help' => 'Include the <b>description and cost</b> in the product dropdown',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Average',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Låst',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Please enter a name',
    'click_plus_to_add_time' => 'Click + to add time',
    'design' => 'Design',
    'password_is_too_short' => 'Password is too short',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Days',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Take Picture',
    'upload_file' => 'Upload File',
    'new_document' => 'New Document',
    'edit_document' => 'Edit Document',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Pris',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'Vi jobber med neste versjon av Invoice Ninja. Klikk på knappen for å starte migrering.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Fult navn',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logger',
    'copy_link' => 'Kopier Lenke',
    'welcome_to_invoice_ninja' => 'Velkommen til Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Advarsel: en ment for bruk på lokal installasjon, passord er ikke sikkert. Klikk her for og vite mer.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'For og oppdatere kjør',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Adresse',
     'enter_your_personal_address' => 'Adresse',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'skrivbar .env fil',
     'env_not_writable' => '.env fil ikke skrivbar for denne brukerkontoen',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Bekreft passord',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Venligst bekreft din epost adresse',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Abonnement',
     'new_subscription' => 'Nytt Abonnement ',
     'deleted_subscription' => 'Abonnement Slettet',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Underdomene ikke tilgjengelig',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
